@@ -8,12 +8,9 @@
  */
 
 #include "configdialog.h"
+#include "config.h"
 #ifdef CONFIG_USE_KDE
-#include <klocale.h>
 #include <kconfig.h>
-#else
-#define i18n(s) tr(s)
-#define I18N_NOOP(s) QT_TR_NOOP(s)
 #endif
 
 #include <qlayout.h>
@@ -21,13 +18,22 @@
 #include <qlabel.h>
 #include <qstring.h>
 #include <qcheckbox.h>
-#include <qgroupbox.h>
 #include <qcombobox.h>
+#include <qlineedit.h>
+#include "qtcompatmac.h"
+#if QT_VERSION >= 0x040000
+#include <QVBoxLayout>
+#include <QHBoxLayout>
+#include <Q3GroupBox>
+#else
+#include <qgroupbox.h>
+#endif
 
 #include "formatconfig.h"
 #include "formatbox.h"
 #include "miscconfig.h"
 #include "commandstable.h"
+#include "kid3.h"
 
 /**
  * Constructor.
@@ -39,52 +45,70 @@
 ConfigDialog::ConfigDialog(QWidget* parent, QString& caption,
 													 KConfigSkeleton* configSkeleton) :
 	KConfigDialog(parent, "configure", configSkeleton,
-								IconList, Ok | Cancel, Ok, true)
+								IconList, Ok | Cancel | Help, Ok, true)
 #else
 ConfigDialog::ConfigDialog(QWidget* parent, QString& caption) :
-	QTabDialog(parent, "configure", true)
+	Q3TabDialog(parent, "configure", true)
 #endif
 {
 	setCaption(caption);
-	QWidget* generalPage = new QWidget(this);
+	QWidget* generalPage = new QWidget;
 	if (generalPage) {
 		QVBoxLayout* vlayout = new QVBoxLayout(generalPage, 6, 6);
 		if (vlayout) {
-			QGroupBox* saveGroupBox = new QGroupBox(1, Horizontal, i18n("Save"), generalPage);
+			Q3GroupBox* saveGroupBox = new Q3GroupBox(1, Qt::Horizontal, i18n("Save"), generalPage);
 			if (saveGroupBox) {
+#if QT_VERSION >= 0x040000
+				saveGroupBox->setInsideMargin(5);
+#endif
 				m_preserveTimeCheckBox = new QCheckBox(i18n("&Preserve file timestamp"), saveGroupBox);
 				vlayout->addWidget(saveGroupBox);
 			}
-			QGroupBox* v2GroupBox = new QGroupBox(1, Horizontal, i18n("ID3v2.3"), generalPage);
+			Q3GroupBox* v2GroupBox = new Q3GroupBox(1, Qt::Horizontal, i18n("ID3v2"), generalPage);
 			if (v2GroupBox) {
+#if QT_VERSION >= 0x040000
+				v2GroupBox->setInsideMargin(5);
+#endif
 				m_totalNumTracksCheckBox = new QCheckBox(i18n("Use &track/total number of tracks format"), v2GroupBox);
+#if defined HAVE_ID3LIB && defined HAVE_TAGLIB
+				QLabel* id3v2VersionLabel = new QLabel(i18n("&Version used for new tags:"), v2GroupBox);
+				m_id3v2VersionComboBox = new QComboBox(v2GroupBox);
+				if (id3v2VersionLabel && m_id3v2VersionComboBox) {
+					m_id3v2VersionComboBox->insertItem(i18n("ID3v2.3.0 (id3lib)"), MiscConfig::ID3v2_3_0);
+					m_id3v2VersionComboBox->insertItem(i18n("ID3v2.4.0 (TagLib)"), MiscConfig::ID3v2_4_0);
+					m_id3v2VersionComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
+					id3v2VersionLabel->setBuddy(m_id3v2VersionComboBox);
+				}
+#endif
 				vlayout->addWidget(v2GroupBox);
 			}
 #ifdef HAVE_VORBIS
-			QGroupBox* vorbisGroupBox = new QGroupBox(2, Horizontal, i18n("Ogg/Vorbis"), generalPage);
+			Q3GroupBox* vorbisGroupBox = new Q3GroupBox(2, Qt::Horizontal, i18n("Ogg/Vorbis"), generalPage);
 			if (vorbisGroupBox) {
+#if QT_VERSION >= 0x040000
+				vorbisGroupBox->setInsideMargin(5);
+#endif
 				QLabel* commentNameLabel = new QLabel(i18n("Comment Field &Name:"), vorbisGroupBox);
 				m_commentNameComboBox = new QComboBox(true, vorbisGroupBox);
 				if (commentNameLabel && m_commentNameComboBox) {
-					static const char* items[] = { "COMMENT", "DESCRIPTION", 0 };
-					m_commentNameComboBox->insertStrList(items);
-#if QT_VERSION >= 0x030100
-					m_commentNameComboBox->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
-#else
+					QStringList items;
+					items += "COMMENT";
+					items += "DESCRIPTION";
+					m_commentNameComboBox->QCM_addItems(items);
 					m_commentNameComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
-#endif
 					commentNameLabel->setBuddy(m_commentNameComboBox);
 				}
 				vlayout->addWidget(vorbisGroupBox);
 			}
 #endif
-#if QT_VERSION >= 300
-			QGroupBox* commandsGroupBox = new QGroupBox(1, Horizontal, i18n("Context &Menu Commands"), generalPage);
+			Q3GroupBox* commandsGroupBox = new Q3GroupBox(1, Qt::Horizontal, i18n("Context &Menu Commands"), generalPage);
 			if (commandsGroupBox) {
+#if QT_VERSION >= 0x040000
+				commandsGroupBox->setInsideMargin(5);
+#endif
 				m_commandsTable = new CommandsTable(commandsGroupBox, "commandsTable");
 				vlayout->addWidget(commandsGroupBox);
 			}
-#endif
 			QSpacerItem* vspacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);
 			vlayout->addItem(vspacer);
 		}
@@ -95,14 +119,14 @@ ConfigDialog::ConfigDialog(QWidget* parent, QString& caption) :
 #endif
 	}
 
-	QWidget* formatPage = new QWidget(this);
+	QWidget* formatPage = new QWidget;
 	if (formatPage) {
 		QVBoxLayout* vlayout = new QVBoxLayout(formatPage, 6, 6);
 		if (vlayout) {
 			QHBoxLayout *fmtLayout = new QHBoxLayout(vlayout);
 			QString fnFormatTitle(i18n("&Filename Format"));
 			fnFormatBox = new FormatBox(fnFormatTitle, formatPage, "fnFormatBox");
-			QString id3FormatTitle(i18n("&ID3 Format"));
+			QString id3FormatTitle(i18n("&Tag Format"));
 			id3FormatBox = new FormatBox(id3FormatTitle, formatPage, "id3FormatBox");
 			if (fmtLayout && fnFormatBox && id3FormatBox) {
 				fmtLayout->addWidget(fnFormatBox);
@@ -115,12 +139,32 @@ ConfigDialog::ConfigDialog(QWidget* parent, QString& caption) :
 		addTab(formatPage, i18n("F&ormat"));
 #endif
 	}
-#ifndef KID3_USE_KCONFIGDIALOG
-	setOkButton();
-	setCancelButton();
+
+	QWidget* proxyPage = new QWidget;
+	if (proxyPage) {
+		QVBoxLayout* vlayout = new QVBoxLayout(proxyPage, 6, 6);
+		if (vlayout) {
+			QHBoxLayout* proxyLayout = new QHBoxLayout(vlayout);
+			m_proxyCheckBox = new QCheckBox(i18n("&Proxy:"), proxyPage);
+			m_proxyLineEdit = new QLineEdit(proxyPage);
+			if (proxyLayout && m_proxyCheckBox && m_proxyLineEdit) {
+				proxyLayout->addWidget(m_proxyCheckBox);
+				proxyLayout->addWidget(m_proxyLineEdit);
+			}
+		}
+#ifdef KID3_USE_KCONFIGDIALOG
+		addPage(proxyPage, i18n("Proxy"), "proxy");
+#else
+		addTab(proxyPage, i18n("&Proxy"));
 #endif
-#if QT_VERSION < 300
-	resize(415, 488);
+	}
+
+#ifndef KID3_USE_KCONFIGDIALOG
+	setHelpButton(i18n("&Help"));
+	connect(this, SIGNAL(helpButtonPressed()), this, SLOT(slotHelp()));
+
+	setOkButton(i18n("&OK"));
+	setCancelButton(i18n("&Cancel"));
 #endif
 }
 
@@ -145,16 +189,15 @@ void ConfigDialog::setConfig(const FormatConfig *fnCfg,
 	id3FormatBox->fromFormatConfig(id3Cfg);
 	m_totalNumTracksCheckBox->setChecked(miscCfg->m_enableTotalNumberOfTracks);
 	m_preserveTimeCheckBox->setChecked(miscCfg->m_preserveTime);
-#if QT_VERSION >= 300
 	m_commandsTable->setCommandList(miscCfg->m_contextMenuCommands);
-#endif
 #ifdef HAVE_VORBIS
-#if QT_VERSION >= 300
 	m_commentNameComboBox->setCurrentText(miscCfg->m_commentName);
-#else
-	m_commentNameComboBox->setEditText(miscCfg->m_commentName);
 #endif
+#if defined HAVE_ID3LIB && defined HAVE_TAGLIB
+	m_id3v2VersionComboBox->setCurrentItem(miscCfg->m_id3v2Version);
 #endif
+	m_proxyCheckBox->setChecked(miscCfg->m_useProxy);
+	m_proxyLineEdit->setText(miscCfg->m_proxy);
 }
 
 /**
@@ -172,10 +215,21 @@ void ConfigDialog::getConfig(FormatConfig *fnCfg,
 	id3FormatBox->toFormatConfig(id3Cfg);
 	miscCfg->m_enableTotalNumberOfTracks = m_totalNumTracksCheckBox->isChecked();
 	miscCfg->m_preserveTime = m_preserveTimeCheckBox->isChecked();
-#if QT_VERSION >= 300
 	m_commandsTable->getCommandList(miscCfg->m_contextMenuCommands);
-#endif
 #ifdef HAVE_VORBIS
 	miscCfg->m_commentName = m_commentNameComboBox->currentText();
 #endif
+#if defined HAVE_ID3LIB && defined HAVE_TAGLIB
+	miscCfg->m_id3v2Version = m_id3v2VersionComboBox->currentItem();
+#endif
+	miscCfg->m_useProxy = m_proxyCheckBox->isChecked();
+	miscCfg->m_proxy = m_proxyLineEdit->text();
+}
+
+/**
+ * Show help.
+ */
+void ConfigDialog::slotHelp()
+{
+	Kid3App::displayHelp("configure-kid3");
 }
