@@ -18,11 +18,16 @@
 #endif
 #endif
 
+#include "qtcompatmac.h"
 #ifdef KID3_USE_KCONFIGDIALOG
 #include <kconfigdialog.h>
 #else
+#if QT_VERSION >= 0x040000
+#include <Q3TabDialog>
+#else
 #include <qtabdialog.h>
 #endif
+#endif
 #include "formatconfig.h"
 
 class FormatBox;
@@ -33,16 +38,20 @@ class CommandsTable;
 class QString;
 class QWidget;
 class QComboBox;
+class QLineEdit;
+
+#ifdef KID3_USE_KCONFIGDIALOG
+typedef KConfigDialog ConfigDialogBaseClass;
+#else
+typedef Q3TabDialog ConfigDialogBaseClass;
+#endif
 
 /**
  * Configuration dialog.
  */
-#ifdef KID3_USE_KCONFIGDIALOG
-class ConfigDialog : public KConfigDialog
-#else
-class ConfigDialog : public QTabDialog
-#endif
+class ConfigDialog : public ConfigDialogBaseClass
 {
+Q_OBJECT
 public:
 	/**
 	 * Constructor.
@@ -78,6 +87,13 @@ public:
 	 */
 	void getConfig(FormatConfig *fnCfg, FormatConfig *id3Cfg,
 				   MiscConfig *miscCfg) const;
+
+protected slots:
+	/**
+	 * Show help.
+	 */
+	virtual void slotHelp();
+
 private:
 	/** Preserve timestamp checkbox */
 	QCheckBox* m_preserveTimeCheckBox;
@@ -85,12 +101,18 @@ private:
 	QCheckBox* m_totalNumTracksCheckBox;
 	/** Comment field name combo box */
 	QComboBox* m_commentNameComboBox;
+	/** ID3v2 version combo box */
+	QComboBox* m_id3v2VersionComboBox;
 	/** Filename Format box */
 	FormatBox *fnFormatBox;
 	/** ID3 Format box */
 	FormatBox *id3FormatBox;
 	/** Commands table */
 	CommandsTable* m_commandsTable;
+	/** Use proxy check box */
+	QCheckBox* m_proxyCheckBox;
+	/** Proxy line edit */
+	QLineEdit* m_proxyLineEdit;
 };
 
 #endif
