@@ -11,17 +11,21 @@
 #define FILELIST_H
 
 #include <qstring.h>
-#include <qlistbox.h>
 #include <qsize.h>
-#include "taggedfile.h"
-
-class MiscConfig;
+#include "filelistitem.h"
+#include "qtcompatmac.h"
+#if QT_VERSION >= 0x040000
+#include <Q3ListBox>
+class Q3Process;
+#else
+#include <qlistbox.h>
 class QProcess;
+#endif
 
 /**
  * List of files to operate on.
  */
-class FileList : public QListBox
+class FileList : public Q3ListBox
 {
 Q_OBJECT
 
@@ -29,7 +33,7 @@ public:
 	/**
 	 * Constructor.
 	 */
-	FileList(QWidget* parent = 0, const char* name = 0, WFlags f = 0);
+	FileList(QWidget* parent = 0, const char* name = 0, Qt::WFlags f = 0);
 	/**
 	 * Destructor.
 	 */
@@ -44,13 +48,13 @@ public:
 	 *
 	 * @return first file.
 	 */
-	TaggedFile *first();
+	FileListItem* first();
 	/**
 	 * Get the next item in the filelist.
 	 *
 	 * @return next file.
 	 */
-	TaggedFile *next();
+	FileListItem* next();
 	/**
 	 * Fill the filelist with the files found in a directory.
 	 *
@@ -76,16 +80,14 @@ public:
 	 * @return absolute path of directory.
 	 */
 	QString getAbsDirname(void) const;
+
 	/**
-	 * Set configuration.
-	 * @param cfg configuration.
+	 * Get the number of files in the file list.
+	 * @return number of files.
 	 */
-	void setMiscConfig(MiscConfig* cfg) { m_miscCfg = cfg; }
-	/**
-	 * Get configuration.
-	 * @return configuration.
-	 */
-	const MiscConfig* getMiscConfig() const { return m_miscCfg; }
+	static int getNumberOfFiles() {
+		return s_instance ? s_instance->count() : 0;
+	}
 
 private slots:
 	/**
@@ -94,7 +96,11 @@ private slots:
 	 * @param item list box item
 	 * @param pos  position where context menu is drawn on screen
 	 */
+#if QT_VERSION >= 0x040000
+	void contextMenu(Q3ListBoxItem* item, const QPoint& pos);
+#else
 	void contextMenu(QListBoxItem* item, const QPoint& pos);
+#endif
 
 	/**
 	 * Execute a context menu command.
@@ -104,14 +110,18 @@ private slots:
 	void executeContextCommand(int id);
 
 private:
+	FileList(const FileList&);
+	FileList& operator=(const FileList&);
+
 	/** path of directory */
 	QString dirname;
 	/** current file */
-	TaggedFile *current_item;
-	/** Miscellaneous configuration */
-	MiscConfig* m_miscCfg;
+	FileListItem* current_item;
 	/** Process for context menu commands */
-	QProcess* m_process;
+	Q3Process* m_process;
+
+	/** Single instance */
+	static FileList* s_instance;
 };
 
 #endif // FILELIST_H
