@@ -7,22 +7,19 @@
  * \date 17 Sep 2003
  */
 
-#include "config.h"
-#ifdef CONFIG_USE_KDE
-#include <klocale.h>
-#else
-#define i18n(s) tr(s)
-#define I18N_NOOP(s) QT_TR_NOOP(s)
-#endif
-
 #include <qlabel.h>
 #include <qcombobox.h>
 #include <qcheckbox.h>
-#include <qtable.h>
 #include <qstring.h>
-#include <qpopupmenu.h>
 #include "formatconfig.h"
 #include "formatbox.h"
+#if QT_VERSION >= 0x040000
+#include <Q3Table>
+#include <Q3PopupMenu>
+#else
+#include <qtable.h>
+#include <qpopupmenu.h>
+#endif
 
 /**
  * Constructor.
@@ -32,7 +29,7 @@
  * @param name   Qt object name
  */
 FormatBox::FormatBox(const QString & title, QWidget *parent, const char *name) :
-	QGroupBox(5, Qt::Vertical, title, parent, name)
+	Q3GroupBox(5, Qt::Vertical, title, parent, name)
 {
 	m_formatEditingCheckBox = new QCheckBox(i18n("Format while editing"),
 																					this, "formatEditingCheckBox");
@@ -55,7 +52,7 @@ FormatBox::FormatBox(const QString & title, QWidget *parent, const char *name) :
 
 	strRepCheckBox = new QCheckBox(this, "strRepCheckBox");
 	strRepCheckBox->setText(i18n("String Replacement:"));
-	strReplTable = new QTable(this, "strReplTable");
+	strReplTable = new Q3Table(this, "strReplTable");
 	strReplTable->setNumRows(1);
 	strReplTable->setNumCols(2);
 	strReplTable->horizontalHeader()->setLabel(0, i18n("From"));
@@ -63,10 +60,8 @@ FormatBox::FormatBox(const QString & title, QWidget *parent, const char *name) :
 	strReplTable->adjustColumn(0);
 	connect(strReplTable, SIGNAL(valueChanged(int,int)),
 			this, SLOT(valueChanged(int,int)));
-#if QT_VERSION >= 300
 	connect(strReplTable, SIGNAL(contextMenuRequested(int,int,const QPoint &)),
 			this, SLOT(contextMenu(int,int,const QPoint&)));
-#endif
 }
 
 /**
@@ -103,11 +98,7 @@ void FormatBox::valueChanged(int row, int col)
  */
 void FormatBox::insertRow(int row)
 {
-#if QT_VERSION >= 300
 	strReplTable->insertRows(row + 1);
-#else
-	strReplTable->setNumRows(row + 2);
-#endif
 }
 
 /**
@@ -117,11 +108,7 @@ void FormatBox::insertRow(int row)
  */
 void FormatBox::deleteRow(int row)
 {
-#if QT_VERSION >= 300
 	strReplTable->removeRow(row);
-#else
-	strReplTable->setNumRows(row);
-#endif
 }
 
 /**
@@ -143,7 +130,7 @@ void FormatBox::clearCell(int row_col)
  */
 void FormatBox::contextMenu(int row, int col, const QPoint &pos)
 {
-	QPopupMenu menu(this);
+	Q3PopupMenu menu(this);
 
 	if (row >= -1) {
 		menu.insertItem(i18n("&Insert row"), this, SLOT(insertRow(int)), 0, 0);
@@ -177,33 +164,21 @@ void FormatBox::fromFormatConfig(const FormatConfig *cfg)
 		 it != cfg->strRepMap.end();
 		 ++it, ++i) {
 		if (strReplTable->numRows() <= i) {
-#if QT_VERSION >= 300
 			strReplTable->insertRows(i);
-#else
-			strReplTable->setNumRows(i + 1);
-#endif
 		}
 		strReplTable->setText(i, 0, it.key());
 		strReplTable->setText(i, 1, it.data());
 	}
 	if (strReplTable->numRows() <= i) {
-#if QT_VERSION >= 300
 		strReplTable->insertRows(i);
-#else
-		strReplTable->setNumRows(i + 1);
-#endif
 	}
 	// add an empty row as last row and remove all rows below
 	strReplTable->setText(i, 0, "");
 	strReplTable->setText(i, 1, "");
 	int row = strReplTable->numRows();
-#if QT_VERSION >= 300
 	while (--row > i) {
 		strReplTable->removeRow(row);
 	}
-#else
-	strReplTable->setNumRows(i + 1);
-#endif
 }
 
 /**
