@@ -12,9 +12,6 @@
 #include <kconfig.h>
 #else
 #include <qstring.h>
-#if QT_VERSION < 0x030100
-#include <qregexp.h>
-#endif
 #endif
 #include "generalconfig.h"
 #include "standardtags.h"
@@ -87,7 +84,7 @@ void FormatConfig::formatString(QString& str) const
 				str = str.upper();
 				break;
 			case FirstLetterUppercase:
-				str = str.at(0).upper() + str.right(str.length() - 1);
+				str = str.at(0).upper() + str.right(str.length() - 1).lower();
 				break;
 			case AllFirstLettersUppercase: {
 				QString newstr;
@@ -174,12 +171,8 @@ void FormatConfig::writeToConfig(
 	config->writeEntry("/FormatWhileEditing", m_formatWhileEditing);
 	config->writeEntry("/CaseConversion", caseConversion);
 	config->writeEntry("/StrRepEnabled", strRepEnabled);
-#if QT_VERSION >= 300
 	config->writeEntry("/StrRepMapKeys", strRepMap.keys());
 	config->writeEntry("/StrRepMapValues", strRepMap.values());
-#else
-	config->writeEntry("/StrRepMap", strRepMap);
-#endif
 	config->endGroup();
 #endif
 }
@@ -220,7 +213,6 @@ void FormatConfig::readFromConfig(
 	caseConversion = (CaseConversion)config->readNumEntry("/CaseConversion",
 														  (int)caseConversion);
 	strRepEnabled = config->readBoolEntry("/StrRepEnabled", strRepEnabled);
-#if QT_VERSION >= 300
 	QStringList keys = config->readListEntry("/StrRepMapKeys");
 	QStringList values = config->readListEntry("/StrRepMapValues");
 	if (!keys.empty() && !values.empty()) {
@@ -232,9 +224,6 @@ void FormatConfig::readFromConfig(
 			strRepMap[*itk] = *itv;
 		}
 	}
-#else
-	strRepMap = config->readMapEntry("/StrRepMap", strRepMap);
-#endif
 	config->endGroup();
 #endif
 }
