@@ -12,19 +12,15 @@
 
 #include <qlabel.h>
 #include <qlayout.h>
-#if QT_VERSION < 300
-#include <qmultilineedit.h>
-#define QTextEdit QMultiLineEdit
-#define setTextFormat(x) isReadOnly() /* just something which does nothing */
-#else
 #include <qtextedit.h>
-#endif
 #include <qdialog.h>
 #include <qlineedit.h>
 #include <qspinbox.h>
 #include <qcombobox.h>
+#include "qtcompatmac.h"
 
-class QListBox;
+class Q3ListBox;
+class QVBoxLayout;
 class QPaintEvent;
 class TaggedFile;
 class FrameList;
@@ -314,14 +310,18 @@ public:
 	 *
 	 * @param lb list box
 	 */
-	static void setListBox(QListBox *lb) { listbox = lb; }
+	static void setListBox(Q3ListBox *lb) { listbox = lb; }
 
- protected:
+protected:
 	/** File containing tags */
 	TaggedFile* m_file;
 
 	/** List box to select frame */
-	static QListBox* listbox;
+	static Q3ListBox* listbox;
+
+private:
+	FrameList(const FrameList&);
+	FrameList& operator=(const FrameList&);
 };
 
 #endif // FRAMELIST_H
