@@ -9,32 +9,40 @@
 
 #include "config.h"
 #ifdef CONFIG_USE_KDE
-#include <klocale.h>
 #include <kfiledialog.h>
 #else
-#define i18n(s) tr(s)
-#define I18N_NOOP(s) QT_TR_NOOP(s)
 #include <qfiledialog.h>
 #endif
 #include <qlayout.h>
-#include <qgroupbox.h>
 #include <qpushbutton.h>
 #include <qfile.h>
 #include <qtextstream.h>
 #include <qapplication.h>
 #include <qclipboard.h>
-#include <qtable.h>
 #include <qlabel.h>
 #include <qcombobox.h>
 #include <qlineedit.h>
 #include <qbitarray.h>
 #include <qcheckbox.h>
 #include <qspinbox.h>
+#include "qtcompatmac.h"
+#if QT_VERSION >= 0x040000
+#include <Q3Table>
+#include <Q3ValueList>
+#include <QHBoxLayout>
+#include <QGridLayout>
+#include <Q3GroupBox>
+#else
+#include <qtable.h>
+#include <qgroupbox.h>
+#endif
 #include "genres.h"
 #include "standardtags.h"
 #include "importparser.h"
 #include "freedbdialog.h"
-#include "freedbconfig.h"
+#include "musicbrainzreleasedialog.h"
+#include "discogsdialog.h"
+#include "kid3.h"
 #include "taggedfile.h"
 #include "importselector.h"
 #ifdef HAVE_TUNEPIMP
@@ -46,7 +54,7 @@
  * Table used for import data.
  * Subclassed to be able to change the cell colors.
  */
-class ImportTable: public QTable {
+class ImportTable: public Q3Table {
 public:
 	/**
 	 * Constructor.
@@ -54,7 +62,7 @@ public:
 	 * @param name   Qt name
 	 */
 	ImportTable(QWidget* parent = 0, const char* name = 0) :
-		QTable(parent, name) {}
+		Q3Table(parent, name) {}
 	/**
 	 * Constructor.
 	 * @param numRows number of rows
@@ -62,7 +70,7 @@ public:
 	 * @param name    Qt name
 	 */
 	ImportTable(int numRows, int numCols, QWidget* parent = 0, const char* name = 0) :
-		QTable(numRows, numCols, parent, name) {} 
+		Q3Table(numRows, numCols, parent, name) {} 
 	/**
 	 * Clear marked rows.
 	 */
@@ -96,24 +104,15 @@ protected:
 	 * @param selected true if selected
 	 * @param cg color group
 	 */
-#if QT_VERSION >= 300
 	virtual void paintCell(QPainter* p, int row, int col, const QRect& cr, bool selected, const QColorGroup& cg) {
 		if (col == 0 && isRowMarked(row)) {
 			QColorGroup g(cg);
 			g.setColor(QColorGroup::Base, QColor("red"));
-			QTable::paintCell(p, row, col, cr, selected, g);
+			Q3Table::paintCell(p, row, col, cr, selected, g);
 		} else {
-			QTable::paintCell(p, row, col, cr, selected, cg);
+			Q3Table::paintCell(p, row, col, cr, selected, cg);
 		}
 	}
-#else
-	virtual void paintCell(QPainter* p, int row, int col, const QRect& cr, bool selected) {
-		if (col == 0 && isRowMarked(row)) {
-			p->setBackgroundColor(QColor("red"));
-		}
-		QTable::paintCell(p, row, col, cr, selected);
-	}
-#endif
 
 private:
 	QBitArray m_markedRows;
@@ -131,15 +130,15 @@ private:
  */
 ImportSelector::ImportSelector(
 	QWidget *parent, ImportTrackDataVector& trackDataList,
-	const char *name, WFlags f) :
-	QVBox(parent, name, f),
+	const char *name, Qt::WFlags f) :
+	Q3VBox(parent, name, f),
 	m_trackDataVector(trackDataList)
 {
 	freedbDialog = 0;
-	freedbCfg = 0;
+	m_musicBrainzReleaseDialog = 0;
+	m_discogsDialog = 0;
 #ifdef HAVE_TUNEPIMP
 	m_musicBrainzDialog = 0;
-	m_musicBrainzCfg = 0;
 #endif
 	importSource = None;
 	header_parser = new ImportParser();
@@ -147,14 +146,12 @@ ImportSelector::ImportSelector(
 	setSpacing(6);
 	setMargin(6);
 	tab = new ImportTable(0, NumColumns, this);
-#if QT_VERSION >= 300
 	tab->setReadOnly(true);
-	tab->setFocusStyle(QTable::FollowStyle);
-#endif
+	tab->setFocusStyle(Q3Table::FollowStyle);
 	tab->setRowMovingEnabled(true);
-	tab->setSelectionMode(QTable::NoSelection);
-	QHeader* hHeader = tab->horizontalHeader();
-	QHeader* vHeader = tab->verticalHeader();
+	tab->setSelectionMode(Q3Table::NoSelection);
+	Q3Header* hHeader = tab->horizontalHeader();
+	Q3Header* vHeader = tab->verticalHeader();
 	hHeader->setLabel(LengthColumn, i18n("Length"));
 	hHeader->setLabel(TrackColumn, i18n("Track"));
 	hHeader->setLabel(TitleColumn, i18n("Title"));
@@ -166,43 +163,47 @@ ImportSelector::ImportSelector(
 	tab->adjustColumn(TrackColumn);
 	tab->adjustColumn(YearColumn);
 
-#if QT_VERSION >= 300
-	QGroupBox *fmtbox = new QGroupBox(3, Qt::Vertical, i18n("Format"), this);
+	Q3GroupBox *fmtbox = new Q3GroupBox(3, Qt::Vertical, i18n("Format"), this);
+#if QT_VERSION >= 0x040000
+	fmtbox->setInsideMargin(5);
+#endif
 	formatComboBox = new QComboBox(false, fmtbox, "formatComboBox");
 	formatComboBox->setEditable(true);
 	headerLineEdit = new QLineEdit(fmtbox);
 	trackLineEdit = new QLineEdit(fmtbox);
 	connect(formatComboBox, SIGNAL(activated(int)), this, SLOT(setFormatLineEdit(int)));
-#endif
 
 	QWidget *butbox = new QWidget(this);
-	QHBoxLayout *butlayout = new QHBoxLayout(butbox);
-	butlayout->setSpacing(6);
-	butlayout->setMargin(6);
+	QGridLayout *butlayout = new QGridLayout(butbox, 2, 7, 0, 6);
 	fileButton = new QPushButton(i18n("From F&ile"), butbox);
-	butlayout->addWidget(fileButton);
+	butlayout->addWidget(fileButton, 0, 0);
 	clipButton = new QPushButton(i18n("From Clip&board"), butbox);
-	butlayout->addWidget(clipButton);
+	butlayout->addWidget(clipButton, 0, 1);
 	freedbButton = new QPushButton(i18n("From &freedb.org"), butbox);
-	butlayout->addWidget(freedbButton);
-#ifdef HAVE_TUNEPIMP
-	m_musicBrainzButton = new QPushButton(i18n("From &MusicBrainz"), butbox);
-	butlayout->addWidget(m_musicBrainzButton);
-#endif
+	butlayout->addWidget(freedbButton, 0, 2);
+	m_discogsButton = new QPushButton(i18n("From Disco&gs"), butbox);
+	butlayout->addWidget(m_discogsButton, 0, 3);
 	QSpacerItem *butspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
 	                                       QSizePolicy::Minimum);
-	butlayout->addItem(butspacer);
+	butlayout->addItem(butspacer, 0, 4);
 	QLabel *destLabel = new QLabel(butbox, "destLabel");
 	destLabel->setText(i18n("D&estination:"));
-	butlayout->addWidget(destLabel);
+	butlayout->addWidget(destLabel, 0, 5);
 	destComboBox = new QComboBox(false, butbox, "destComboBox");
-	destComboBox->insertItem("ID3v1", DestV1);
-	destComboBox->insertItem("ID3v2", DestV2);
+	destComboBox->insertItem(i18n("Tag 1"), DestV1);
+	destComboBox->insertItem(i18n("Tag 2"), DestV2);
 	destLabel->setBuddy(destComboBox);
-	butlayout->addWidget(destComboBox);
+	butlayout->addWidget(destComboBox, 0, 7);
+
+	m_musicBrainzReleaseButton = new QPushButton(i18n("From MusicBrainz &Release"), butbox);
+	butlayout->addMultiCellWidget(m_musicBrainzReleaseButton, 1, 1, 0, 1);
+#ifdef HAVE_TUNEPIMP
+	m_musicBrainzButton = new QPushButton(i18n("From &MusicBrainz Fingerprint"), butbox);
+	butlayout->addMultiCellWidget(m_musicBrainzButton, 1, 1, 2, 3);
+#endif
 
 	QWidget* matchBox = new QWidget(this, "matchBox");
-	QHBoxLayout* matchLayout = new QHBoxLayout(matchBox, 6, 6, "matchLayout");
+	QHBoxLayout* matchLayout = new QHBoxLayout(matchBox, 0, 6, "matchLayout");
 	mismatchCheckBox = new QCheckBox(
 		i18n("Check maximum allowable time &difference (sec):"), matchBox ,
 		"mismatchCheckBox");
@@ -225,6 +226,8 @@ ImportSelector::ImportSelector(
 	connect(fileButton, SIGNAL(clicked()), this, SLOT(fromFile()));
 	connect(clipButton, SIGNAL(clicked()), this, SLOT(fromClipboard()));
 	connect(freedbButton, SIGNAL(clicked()), this, SLOT(fromFreedb()));
+	connect(m_musicBrainzReleaseButton, SIGNAL(clicked()), this, SLOT(fromMusicBrainzRelease()));
+	connect(m_discogsButton, SIGNAL(clicked()), this, SLOT(fromDiscogs()));
 #ifdef HAVE_TUNEPIMP
 	connect(m_musicBrainzButton, SIGNAL(clicked()), this, SLOT(fromMusicBrainz()));
 #endif
@@ -248,6 +251,16 @@ ImportSelector::~ImportSelector()
 		delete freedbDialog;
 		freedbDialog = 0;
 	}
+	if (m_musicBrainzReleaseDialog) {
+		m_musicBrainzReleaseDialog->disconnect();
+		delete m_musicBrainzReleaseDialog;
+		m_musicBrainzReleaseDialog = 0;
+	}
+	if (m_discogsDialog) {
+		m_discogsDialog->disconnect();
+		delete m_discogsDialog;
+		m_discogsDialog = 0;
+	}
 #ifdef HAVE_TUNEPIMP
 	if (m_musicBrainzDialog) {
 		m_musicBrainzDialog->disconnect();
@@ -263,11 +276,23 @@ ImportSelector::~ImportSelector()
 void ImportSelector::clear()
 {
 	tab->setNumRows(0);
+	destComboBox->setCurrentItem(
+		static_cast<int>(Kid3App::s_genCfg.importDestV1 ? DestV1 : DestV2));
+
+	formatHeaders = Kid3App::s_genCfg.importFormatHeaders;
+	formatTracks = Kid3App::s_genCfg.importFormatTracks;
+	formatComboBox->clear();
+	formatComboBox->insertStringList(Kid3App::s_genCfg.importFormatNames);
+	formatComboBox->setCurrentItem(Kid3App::s_genCfg.importFormatIdx);
+	setFormatLineEdit(Kid3App::s_genCfg.importFormatIdx);
+
+	mismatchCheckBox->setChecked(Kid3App::s_genCfg.enableTimeDifferenceCheck);
+	maxDiffSpinBox->setValue(Kid3App::s_genCfg.maxTimeDifference);
 }
 
 /**
  * Look for album specific information (artist, album, year, genre) in
- * a header (e.g. in a freedb header).
+ * a header.
  *
  * @param st standard tags to put resulting values in,
  *           fields which are not found are not touched.
@@ -277,15 +302,7 @@ void ImportSelector::clear()
 bool ImportSelector::parseHeader(StandardTags &st)
 {
 	int pos = 0;
-	header_parser->setFormat(
-		importSource == Freedb ? "freedb_header" :
-#if QT_VERSION >= 300
-		headerLineEdit->text()
-#else
-		/* dummy format to indicate a header format */
-		"%y(+\\d)"
-#endif
-		);
+	header_parser->setFormat(headerLineEdit->text());
 	return header_parser->getNextTags(text, st, pos);
 }
 
@@ -303,7 +320,7 @@ void ImportSelector::fromFile()
 #endif
 	if (!fn.isEmpty()) {
 		QFile file(fn);
-		if (file.open(IO_ReadOnly)) {
+		if (file.open(QCM_ReadOnly)) {
 			QTextStream stream(&file);
 			text = stream.read();
 			if (!text.isNull()) {
@@ -347,14 +364,11 @@ void ImportSelector::fromClipboard()
 void ImportSelector::fromFreedb()
 {
 	if (!freedbDialog) {
-		freedbDialog = new FreedbDialog(this);
-		connect(freedbDialog, SIGNAL(albumDataReceived(QString)),
-				this, SLOT(freedbAlbumDataReceived(QString)));
+		freedbDialog = new FreedbDialog(this, m_trackDataVector);
+		connect(freedbDialog, SIGNAL(trackDataUpdated()),
+						this, SLOT(showPreview()));
 	}
 	if (freedbDialog) {
-		if (freedbCfg) {
-			freedbDialog->setFreedbConfig(freedbCfg);
-		}
 		freedbDialog->setArtistAlbum(m_trackDataVector.artist,
 																 m_trackDataVector.album);
 		(void)freedbDialog->exec();
@@ -362,15 +376,36 @@ void ImportSelector::fromFreedb()
 }
 
 /**
- * Called when freedb.org album data is received.
- *
- * @param txt text containing album data from freedb.org
+ * Import from MusicBrainz release database and preview in table.
  */
-void ImportSelector::freedbAlbumDataReceived(QString txt)
+void ImportSelector::fromMusicBrainzRelease()
 {
-	text = txt;
-	updateTrackData(Freedb);
-	showPreview();
+	if (!m_musicBrainzReleaseDialog) {
+		m_musicBrainzReleaseDialog = new MusicBrainzReleaseDialog(this, m_trackDataVector);
+		connect(m_musicBrainzReleaseDialog, SIGNAL(trackDataUpdated()),
+						this, SLOT(showPreview()));
+	}
+	if (m_musicBrainzReleaseDialog) {
+		m_musicBrainzReleaseDialog->setArtistAlbum(m_trackDataVector.artist,
+																							 m_trackDataVector.album);
+		(void)m_musicBrainzReleaseDialog->exec();
+	}
+}
+/**
+ * Import from www.discogs.com and preview in table.
+ */
+void ImportSelector::fromDiscogs()
+{
+	if (!m_discogsDialog) {
+		m_discogsDialog = new DiscogsDialog(this, m_trackDataVector);
+		connect(m_discogsDialog, SIGNAL(trackDataUpdated()),
+						this, SLOT(showPreview()));
+	}
+	if (m_discogsDialog) {
+		m_discogsDialog->setArtistAlbum(m_trackDataVector.artist,
+																		m_trackDataVector.album);
+		(void)m_discogsDialog->exec();
+	}
 }
 
 /**
@@ -380,10 +415,8 @@ void ImportSelector::freedbAlbumDataReceived(QString txt)
  */
 void ImportSelector::setFormatLineEdit(int index)
 {
-#if QT_VERSION >= 300
 	headerLineEdit->setText(formatHeaders[index]);
 	trackLineEdit->setText(formatTracks[index]);
-#endif
 }
 
 /**
@@ -401,23 +434,14 @@ bool ImportSelector::updateTrackData(ImportSource impSrc) {
 
 	StandardTags st(st_hdr);
 	bool start = true;
-#if QT_VERSION >= 300
-	ImportTrackDataVector::iterator
-#else
-	ImportTrackDataVector::Iterator
-#endif
-		it = m_trackDataVector.begin();
+	ImportTrackDataVector::iterator it = m_trackDataVector.begin();
 	bool atTrackDataListEnd = (it == m_trackDataVector.end());
 	while (getNextTags(st, start)) {
 		start = false;
 		if (atTrackDataListEnd) {
 			ImportTrackData trackData;
 			trackData.setStandardTags(st);
-#if QT_VERSION >= 300
 			m_trackDataVector.push_back(trackData);
-#else
-			m_trackDataVector.append(trackData);
-#endif
 		} else {
 			(*it).setStandardTags(st);
 			++it;
@@ -428,11 +452,7 @@ bool ImportSelector::updateTrackData(ImportSource impSrc) {
 	st.setInactive();
 	while (!atTrackDataListEnd) {
 		if ((*it).getFileDuration() == 0) {
-#if QT_VERSION >= 300
 			it = m_trackDataVector.erase(it);
-#else
-			it = m_trackDataVector.remove(it);
-#endif
 		} else {
 			(*it).setStandardTags(st);
 			(*it).setImportDuration(0);
@@ -443,16 +463,10 @@ bool ImportSelector::updateTrackData(ImportSource impSrc) {
 
 	if (!start) {
 		/* start is false => tags were found */
-		QValueList<int>* trackDuration = getTrackDurations();
+		Q3ValueList<int>* trackDuration = getTrackDurations();
 		if (trackDuration) {
 			it = m_trackDataVector.begin();
-			for (
-#if QT_VERSION >= 300
-				 QValueList<int>::const_iterator
-#else
-				 QValueList<int>::ConstIterator
-#endif
-					 tdit = trackDuration->begin();
+			for (Q3ValueList<int>::const_iterator tdit = trackDuration->begin();
 					 tdit != trackDuration->end();
 					 ++tdit) {
 				if (it != m_trackDataVector.end()) {
@@ -474,14 +488,8 @@ bool ImportSelector::updateTrackData(ImportSource impSrc) {
 void ImportSelector::showPreview() {
 	tab->setNumRows(0);
 	int row = 0;
-	QHeader* vHeader = tab->verticalHeader();
-	for (
-#if QT_VERSION >= 300
-		 ImportTrackDataVector::const_iterator
-#else
-		 ImportTrackDataVector::ConstIterator
-#endif
-			 it = m_trackDataVector.begin();
+	Q3Header* vHeader = tab->verticalHeader();
+	for (ImportTrackDataVector::const_iterator it = m_trackDataVector.begin();
 			 it != m_trackDataVector.end();
 			 ++it) {
 		tab->setNumRows(row + 1);
@@ -528,13 +536,7 @@ void ImportSelector::showPreview() {
 	if (diffCheckEnable) {
 		bool tracksAvailable = false;
 		row = 0;
-		for (
-#if QT_VERSION >= 300
-			ImportTrackDataVector::const_iterator
-#else
-			ImportTrackDataVector::ConstIterator
-#endif
-				 it = m_trackDataVector.begin();
+		for (ImportTrackDataVector::const_iterator it = m_trackDataVector.begin();
 				 it != m_trackDataVector.end();
 				 ++it) {
 			int fileDuration = (*it).getFileDuration();
@@ -572,29 +574,11 @@ bool ImportSelector::getNextTags(StandardTags &st, bool start)
 	static int pos = 0;
 	if (start || pos == 0) {
 		pos = 0;
-		track_parser->setFormat(
-			importSource == Freedb ? "freedb_tracks" :
-#if QT_VERSION >= 300
-			trackLineEdit->text()
-#else
-			/* dummy format to indicate a track format */
-			"%t(\\d+)"
-#endif
-			, true);
+		track_parser->setFormat(trackLineEdit->text(), true);
 	}
 	return track_parser->getNextTags(text, st, pos);
 }
 
-/**
- * Set ID3v1 or ID3v2 tags as import destination.
- *
- * @param dest DestV1 or DestV2 for ID3v1 or ID3v2
- */
-void ImportSelector::setDestination(ImportSelector::Destination dest)
-{
-	destComboBox->setCurrentItem((int)dest);
-}
-
 /**
  * Get import destination.
  *
@@ -606,76 +590,20 @@ ImportSelector::Destination ImportSelector::getDestination()
 }
 
 /**
- * Set import format regexp.
- *
- * @param names   import format names list
- * @param headers import format header regexps
- * @param tracks  import format track regexps
- * @param idx     selected index
+ * Save the local settings to the configuration.
  */
-void ImportSelector::setImportFormat(const QStringList &names,
-									 const QStringList &headers,
-									 const QStringList &tracks,
-									 int idx)
+void ImportSelector::saveConfig()
 {
-#if QT_VERSION >= 300
-	formatHeaders = headers;
-	formatTracks = tracks;
-	formatComboBox->clear();
-	formatComboBox->insertStringList(names);
-	formatComboBox->setCurrentItem(idx);
-	setFormatLineEdit(idx);
-#endif
-}
+	Kid3App::s_genCfg.importDestV1 = 
+		(destComboBox->currentItem() == static_cast<int>(ImportSelector::DestV1));
 
-/**
- * Get import format regexp.
- *
- * @param name   import format name
- * @param header import format header regexp
- * @param track  import format track regexp
- *
- * @return index of current selection.
- */
-int ImportSelector::getImportFormat(QString &name,
-									QString &header,
-									QString &track) const
-{
-#if QT_VERSION >= 300
-	name = formatComboBox->currentText();
-	header = headerLineEdit->text();
-	track = trackLineEdit->text();
-	return formatComboBox->currentItem();
-#else
-	return 0;
-#endif
-}
+	Kid3App::s_genCfg.importFormatIdx = formatComboBox->currentItem();
+	Kid3App::s_genCfg.importFormatNames[Kid3App::s_genCfg.importFormatIdx] = formatComboBox->currentText();
+	Kid3App::s_genCfg.importFormatHeaders[Kid3App::s_genCfg.importFormatIdx] = headerLineEdit->text();
+	Kid3App::s_genCfg.importFormatTracks[Kid3App::s_genCfg.importFormatIdx] = trackLineEdit->text();
+	getTimeDifferenceCheck(Kid3App::s_genCfg.enableTimeDifferenceCheck,
+												 Kid3App::s_genCfg.maxTimeDifference);
 
-/**
- * Set freedb.org configuration.
- *
- * @param cfg freedb configuration.
- */
-void ImportSelector::setFreedbConfig(const FreedbConfig *cfg)
-{
-	freedbCfg = cfg;
-}
-
-/**
- * Get freedb.org configuration.
- *
- * @param cfg freedb configuration.
- */
-void ImportSelector::getFreedbConfig(FreedbConfig *cfg) const
-{
-	if (freedbDialog) {
-		freedbDialog->getFreedbConfig(cfg);
-	} else {
-		// freedb dialog does not exist => copy configuration which was set
-		if (freedbCfg && (freedbCfg != cfg)) {
-			*cfg = *freedbCfg;
-		}
-	}
 }
 
 /**
@@ -684,42 +612,20 @@ void ImportSelector::getFreedbConfig(FreedbConfig *cfg) const
  * @return list with track durations,
  *         0 if no track durations found.
  */
-QValueList<int>* ImportSelector::getTrackDurations()
+Q3ValueList<int>* ImportSelector::getTrackDurations()
 {
-	QValueList<int>* lst = 0;
+	Q3ValueList<int>* lst = 0;
 	if (header_parser && ((lst = header_parser->getTrackDurations()) != 0) &&
-#if QT_VERSION >= 300
-		(lst->size() > 0)
-#else
-		(lst->count() > 0)
-#endif
-		) {
+			(lst->size() > 0)) {
 		return lst;
 	} else if (track_parser && ((lst = track_parser->getTrackDurations()) != 0) &&
-#if QT_VERSION >= 300
-		(lst->size() > 0)
-#else
-		(lst->count() > 0)
-#endif
-	   ) {
+						 (lst->size() > 0)) {
 		return lst;
 	} else {
 		return 0;
 	}
 }
 
-/**
- * Set time difference check configuration.
- *
- * @param enable  true to enable check
- * @param maxDiff maximum allowable time difference
- */ 
-void ImportSelector::setTimeDifferenceCheck(bool enable, int maxDiff)
-{
-	mismatchCheckBox->setChecked(enable);
-	maxDiffSpinBox->setValue(maxDiff);
-}
-
 /**
  * Get time difference check configuration.
  *
@@ -752,11 +658,7 @@ void ImportSelector::moveTableRow(int, int fromIndex, int toIndex) {
 	if (toIndex > fromIndex && toIndex > 0) {
 		--toIndex;
 	}
-#if QT_VERSION >= 300
 	int numTracks = static_cast<int>(m_trackDataVector.size());
-#else
-	int numTracks = static_cast<int>(m_trackDataVector.count());
-#endif
 	if (fromIndex < numTracks && toIndex < numTracks) {
 		// swap elements but keep file durations and names
 		ImportTrackData fromData(m_trackDataVector[fromIndex]);
@@ -771,7 +673,7 @@ void ImportSelector::moveTableRow(int, int fromIndex, int toIndex) {
 }
 
 /**
- * Import from freedb.org and preview in table.
+ * Import from MusicBrainz and preview in table.
  */
 void ImportSelector::fromMusicBrainz()
 {
@@ -782,50 +684,12 @@ void ImportSelector::fromMusicBrainz()
 						this, SLOT(showPreview()));
 	}
 	if (m_musicBrainzDialog) {
-		if (m_musicBrainzCfg) {
-			m_musicBrainzDialog->setMusicBrainzConfig(m_musicBrainzCfg);
-		}
 		m_musicBrainzDialog->initTable();
 		(void)m_musicBrainzDialog->exec();
 	}
 #endif
 }
 
-#ifdef HAVE_TUNEPIMP
-/**
- * Set MusicBrainz configuration.
- *
- * @param cfg MusicBrainz configuration.
- */
-void ImportSelector::setMusicBrainzConfig(const MusicBrainzConfig* cfg)
-{
-	m_musicBrainzCfg = cfg;
-}
-#else
-void ImportSelector::setMusicBrainzConfig(const MusicBrainzConfig*) {}
-#endif
-
-#ifdef HAVE_TUNEPIMP
-/**
- * Get MusicBrainz configuration.
- *
- * @param cfg MusicBrainz configuration.
- */
-void ImportSelector::getMusicBrainzConfig(MusicBrainzConfig* cfg) const
-{
-	if (m_musicBrainzDialog) {
-		m_musicBrainzDialog->getMusicBrainzConfig(cfg);
-	} else {
-		// MusicBrainz dialog does not exist => copy configuration which was set
-		if (m_musicBrainzCfg && (m_musicBrainzCfg != cfg)) {
-			*cfg = *m_musicBrainzCfg;
-		}
-	}
-}
-#else
-void ImportSelector::getMusicBrainzConfig(MusicBrainzConfig*) const {}
-#endif
-
 /**
  * Match import data with length.
  */
@@ -839,11 +703,7 @@ void ImportSelector::matchWithLength()
 	};
 
 	bool failed = false;
-#if QT_VERSION >= 300
 	unsigned numTracks = m_trackDataVector.size();
-#else
-	unsigned numTracks = m_trackDataVector.count();
-#endif
 	if (numTracks > 0) {
 		bool diffCheckEnable;
 		int maxDiff;
@@ -852,13 +712,7 @@ void ImportSelector::matchWithLength()
 		MatchData* md = new MatchData[numTracks];
 		unsigned numFiles = 0, numImports = 0;
 		unsigned i = 0;
-		for (
-#if QT_VERSION >= 300
-			ImportTrackDataVector::const_iterator
-#else
-			ImportTrackDataVector::ConstIterator
-#endif
-				 it = m_trackDataVector.begin();
+		for (ImportTrackDataVector::const_iterator it = m_trackDataVector.begin();
 				 it != m_trackDataVector.end();
 				 ++it) {
 			if (i >= numTracks) {
@@ -974,23 +828,13 @@ void ImportSelector::matchWithTrack()
 	};
 
 	bool failed = false;
-#if QT_VERSION >= 300
 	unsigned numTracks = m_trackDataVector.size();
-#else
-	unsigned numTracks = m_trackDataVector.count();
-#endif
 	if (numTracks > 0) {
 		MatchData* md = new MatchData[numTracks];
 
 		// 1st pass: Get track data and keep correct assignments.
 		unsigned i = 0;
-		for (
-#if QT_VERSION >= 300
-			ImportTrackDataVector::const_iterator
-#else
-			ImportTrackDataVector::ConstIterator
-#endif
-				 it = m_trackDataVector.begin();
+		for (ImportTrackDataVector::const_iterator it = m_trackDataVector.begin();
 				 it != m_trackDataVector.end();
 				 ++it) {
 			if (i >= numTracks) {
@@ -1068,23 +912,14 @@ void ImportSelector::matchWithTitle()
 	};
 
 	bool failed = false;
-#if QT_VERSION >= 300
 	unsigned numTracks = m_trackDataVector.size();
-#else
-	unsigned numTracks = m_trackDataVector.count();
-#endif
 	if (numTracks > 0) {
 		MatchData* md = new MatchData[numTracks];
 		unsigned numFiles = 0, numImports = 0;
 		QRegExp nonWordCharRegExp("\\W");
+		QRegExp nonLetterSpaceRegExp("[^a-z ]");
 		unsigned i = 0;
-		for (
-#if QT_VERSION >= 300
-			ImportTrackDataVector::const_iterator
-#else
-			ImportTrackDataVector::ConstIterator
-#endif
-				 it = m_trackDataVector.begin();
+		for (ImportTrackDataVector::const_iterator it = m_trackDataVector.begin();
 				 it != m_trackDataVector.end();
 				 ++it) {
 			if (i >= numTracks) {
@@ -1100,11 +935,15 @@ void ImportSelector::matchWithTitle()
 				} else {
 					fileName = fileName.mid(startIndex);
 				}
-				md[i].fileWords = QStringList::split(nonWordCharRegExp, fileName.lower());
+				md[i].fileWords = QStringList::split(
+					nonWordCharRegExp, fileName.lower().
+					replace(nonLetterSpaceRegExp, " "));
 			}
 			if (!(*it).title.isEmpty()) {
 				++numImports;
-				md[i].titleWords = QStringList::split(nonWordCharRegExp, (*it).title.lower());
+				md[i].titleWords = QStringList::split(
+					nonWordCharRegExp, (*it).title.lower().
+					replace(nonLetterSpaceRegExp, " "));
 			}
 			md[i].assignedTo = -1;
 			md[i].assignedFrom = -1;
