@@ -12,10 +12,11 @@
 
 #include "standardtags.h"
 #include <qglobal.h>
-#if QT_VERSION >= 300
-#include <qvaluevector.h>
+#include "qtcompatmac.h"
+#if QT_VERSION >= 0x040000
+#include <Q3ValueVector>
 #else
-#include <qvaluelist.h>
+#include <qvaluevector.h>
 #endif
 
 /**
@@ -83,13 +84,7 @@ private:
 	QString m_absFilename;
 };
 
-class ImportTrackDataVector : public 
-#if QT_VERSION >= 300
-QValueVector<ImportTrackData>
-#else
-QValueList<ImportTrackData>
-#endif
-{
+class ImportTrackDataVector : public Q3ValueVector<ImportTrackData> {
 public:
 	QString artist;
 	QString album;
