@@ -22,15 +22,15 @@
 
 /** Default name filter */
 #ifdef HAVE_VORBIS
-const QString MiscConfig::defaultNameFilter(
+const char* const MiscConfig::defaultNameFilter =
 	"*.mp3 *.MP3 *.Mp3 *.mP3 "
-	"*.ogg *.ogG *.oGg *.oGG *.Ogg *.OgG *.OGg *.OGG");
+	"*.ogg *.ogG *.oGg *.oGG *.Ogg *.OgG *.OGg *.OGG";
 #else
-const QString MiscConfig::defaultNameFilter("*.mp3 *.MP3 *.Mp3 *.mP3");
+const char* const MiscConfig::defaultNameFilter = "*.mp3 *.MP3 *.Mp3 *.mP3";
 #endif
 
 /** Default value for comment name */
-const QString MiscConfig::defaultCommentName("COMMENT");
+const char* const MiscConfig::defaultCommentName = "COMMENT";
 
 /** Default filename format list */
 static const char* fnFmt[] = {
@@ -90,8 +90,11 @@ MiscConfig::MiscConfig(const QString &group) :
 	formatItem(0),
 	dirFormatText(defaultDirFmtList[0]),
 	dirFormatItem(0),
+	m_renDirSrcV1(true),
 	m_hideV1(false),
-	m_hideV2(false)
+	m_hideV2(false),
+	m_id3v2Version(ID3v2_3_0),
+	m_useProxy(false)
 #ifndef CONFIG_USE_KDE
 	, windowWidth(-1), windowHeight(-1)
 #endif
@@ -124,17 +127,19 @@ void MiscConfig::writeToConfig(
 	config->writeEntry("FormatText2", formatText);
 	config->writeEntry("DirFormatItem", dirFormatItem);
 	config->writeEntry("DirFormatText", dirFormatText);
+	config->writeEntry("RenameDirectorySourceV1", m_renDirSrcV1);
 	config->writeEntry("EnableTotalNumberOfTracks", m_enableTotalNumberOfTracks);
 	config->writeEntry("PreserveTime", m_preserveTime);
 	config->writeEntry("CommentName", m_commentName);
-#if QT_VERSION >= 300
 	config->writeEntry("ContextMenuCommands", m_contextMenuCommands);
-#endif
 	config->writeEntry("SplitterSizes", splitterSizes);
 	config->writeEntry("VSplitterSizes", m_vSplitterSizes);
 	config->writeEntry("CustomGenres", m_customGenres);
 	config->writeEntry("HideV1", m_hideV1);
 	config->writeEntry("HideV2", m_hideV2);
+	config->writeEntry("ID3v2Version", m_id3v2Version);
+	config->writeEntry("UseProxy", m_useProxy);
+	config->writeEntry("Proxy", m_proxy);
 #else
 	config->beginGroup("/" + group);
 	config->writeEntry("/NameFilter2", nameFilter);
@@ -142,16 +147,13 @@ void MiscConfig::writeToConfig(
 	config->writeEntry("/FormatText2", formatText);
 	config->writeEntry("/DirFormatItem", dirFormatItem);
 	config->writeEntry("/DirFormatText", dirFormatText);
+	config->writeEntry("/RenameDirectorySourceV1", m_renDirSrcV1);
 	config->writeEntry("/EnableTotalNumberOfTracks", m_enableTotalNumberOfTracks);
 	config->writeEntry("/PreserveTime", m_preserveTime);
 	config->writeEntry("/CommentName", m_commentName);
 
-#if QT_VERSION >= 300
 	config->writeEntry("/ContextMenuCommands", m_contextMenuCommands);
-	QValueList<int>::const_iterator it;
-#else
-	QValueListConstIterator<int> it;
-#endif
+	Q3ValueList<int>::const_iterator it;
 	int i;
 	for (it = splitterSizes.begin(), i = 0;
 		 it != splitterSizes.end();
@@ -166,6 +168,9 @@ void MiscConfig::writeToConfig(
 	config->writeEntry("/CustomGenres", m_customGenres);
 	config->writeEntry("/HideV1", m_hideV1);
 	config->writeEntry("/HideV2", m_hideV2);
+	config->writeEntry("/ID3v2Version", m_id3v2Version);
+	config->writeEntry("/UseProxy", m_useProxy);
+	config->writeEntry("/Proxy", m_proxy);
 	config->writeEntry("/WindowWidth", windowWidth);
 	config->writeEntry("/WindowHeight", windowHeight);
 	config->endGroup();
@@ -194,10 +199,10 @@ void MiscConfig::readFromConfig(
 	    config->readNumEntry("FormatItem", 0);
 	dirFormatItem =
 	    config->readNumEntry("DirFormatItem", 0);
+	m_renDirSrcV1 = config->readBoolEntry("RenameDirectorySourceV1", m_renDirSrcV1);
 	m_enableTotalNumberOfTracks = config->readBoolEntry("EnableTotalNumberOfTracks", m_enableTotalNumberOfTracks);
 	m_preserveTime = config->readBoolEntry("PreserveTime", m_preserveTime);
 	m_commentName = config->readEntry("CommentName", defaultCommentName);
-#if QT_VERSION >= 300
 	m_contextMenuCommands = config->readListEntry("ContextMenuCommands"
 #if KDE_VERSION >= 0x30200
 																								, QStringList("xmms")
@@ -207,12 +212,14 @@ void MiscConfig::readFromConfig(
 	    config->readEntry("FormatText2", defaultFnFmtList[0]);
 	dirFormatText =
 	    config->readEntry("DirFormatText", defaultDirFmtList[0]);
-#endif
 	splitterSizes = config->readIntListEntry("SplitterSizes");
 	m_vSplitterSizes = config->readIntListEntry("VSplitterSizes");
 	m_customGenres = config->readListEntry("CustomGenres");
 	m_hideV1 = config->readBoolEntry("HideV1", m_hideV1);
 	m_hideV2 = config->readBoolEntry("HideV2", m_hideV2);
+	m_id3v2Version = config->readNumEntry("ID3v2Version", ID3v2_3_0);
+	m_useProxy = config->readBoolEntry("UseProxy", m_useProxy);
+	m_proxy = config->readEntry("Proxy", m_proxy);
 #else
 	config->beginGroup("/" + group);
 	nameFilter =
@@ -221,29 +228,24 @@ void MiscConfig::readFromConfig(
 	    config->readNumEntry("/FormatItem", 0);
 	dirFormatItem =
 	    config->readNumEntry("/DirFormatItem", 0);
+	m_renDirSrcV1 = config->readBoolEntry("/RenameDirectorySourceV1", m_renDirSrcV1);
 	m_enableTotalNumberOfTracks = config->readBoolEntry("/EnableTotalNumberOfTracks", m_enableTotalNumberOfTracks);
 	m_preserveTime = config->readBoolEntry("/PreserveTime", m_preserveTime);
 	m_commentName = config->readEntry("/CommentName", defaultCommentName);
-#if QT_VERSION >= 300
 	bool ok;
 	m_contextMenuCommands = config->readListEntry("/ContextMenuCommands", &ok);
 	if (!ok) {
-		m_contextMenuCommands = "xmms";
+		m_contextMenuCommands = QStringList("xmms");
 	}
 	formatText =
 	    config->readEntry("/FormatText2", defaultFnFmtList[0]);
 	dirFormatText =
 	    config->readEntry("/DirFormatText", defaultDirFmtList[0]);
-#endif
 	splitterSizes.clear();
 	for (int i = 0; i < 5; ++i) {
 		int val = config->readNumEntry("/SplitterSize" + QString::number(i), -1);
 		if (val != -1) {
-#if QT_VERSION >= 300
 			splitterSizes.push_back(val);
-#else
-			splitterSizes.append(val);
-#endif
 		} else {
 			break;
 		}
@@ -252,11 +254,7 @@ void MiscConfig::readFromConfig(
 	for (int j = 0; j < 5; ++j) {
 		int val = config->readNumEntry("/VSplitterSize" + QString::number(j), -1);
 		if (val != -1) {
-#if QT_VERSION >= 300
 			m_vSplitterSizes.push_back(val);
-#else
-			m_vSplitterSizes.append(val);
-#endif
 		} else {
 			break;
 		}
@@ -264,6 +262,9 @@ void MiscConfig::readFromConfig(
 	m_customGenres = config->readListEntry("/CustomGenres");
 	m_hideV1 = config->readBoolEntry("/HideV1", m_hideV1);
 	m_hideV2 = config->readBoolEntry("/HideV2", m_hideV2);
+	m_id3v2Version = config->readNumEntry("/ID3v2Version", ID3v2_3_0);
+	m_useProxy = config->readBoolEntry("/UseProxy", m_useProxy);
+	m_proxy = config->readEntry("/Proxy", m_proxy);
 	windowWidth = config->readNumEntry("/WindowWidth", -1);
 	windowHeight = config->readNumEntry("/WindowHeight", -1);
 	config->endGroup();
