@@ -10,8 +10,13 @@
 #ifndef MISCCONFIG_H
 #define MISCCONFIG_H
 
-#include <qvaluelist.h>
 #include <qstringlist.h>
+#include "qtcompatmac.h"
+#if QT_VERSION >= 0x040000
+#include <Q3ValueList>
+#else
+#include <qvaluelist.h>
+#endif
 #include "config.h"
 #include "generalconfig.h"
 
@@ -24,6 +29,12 @@ class StandardTags;
 class MiscConfig : public GeneralConfig
 {
 public:
+	/** The ID3v2 version used for new tags. */
+	enum Id3v2Version {
+		ID3v2_3_0 = 0,
+		ID3v2_4_0 = 1
+	};
+
 	/**
 	 * Constructor.
 	 */
@@ -73,10 +84,12 @@ public:
 	QString dirFormatText;
 	/** index of directory name format selected */
 	int dirFormatItem;
+	/** true to rename directory from ID3v1 tags, else ID3v2 tags */
+	bool m_renDirSrcV1;
 	/** size of splitter in main window */
-	QValueList<int> splitterSizes;
+	Q3ValueList<int> splitterSizes;
 	/** size of file/dirlist splitter */
-	QValueList<int> m_vSplitterSizes;
+	Q3ValueList<int> m_vSplitterSizes;
 	/** commands available in context menu */
 	QStringList m_contextMenuCommands;
 	/** custom genres for ID3v2.3 */
@@ -85,6 +98,12 @@ public:
 	bool m_hideV1;
 	/** true to hide ID3v2.3 controls */
 	bool m_hideV2;
+	/** version used for new ID3v2 tags */
+	int m_id3v2Version;
+	/** true if proxy is used */
+	bool m_useProxy;
+	/** proxy used for access */
+	QString m_proxy;
 #ifndef CONFIG_USE_KDE
 	/** mainwindow width */
 	int windowWidth;
@@ -93,9 +112,9 @@ public:
 #endif
 
 	/** Default name filter */
-	static const QString defaultNameFilter;
+	static const char* const defaultNameFilter;
 	/** Default value for comment name */
-	static const QString defaultCommentName;
+	static const char* const defaultCommentName;
 	/** Default filename format list */
 	static const char** defaultFnFmtList;
 	/** Default directory format list */
