@@ -7,20 +7,27 @@
  * \date 9 Jan 2003
  */
 
-#include "config.h"
+#include "mp3file.h"
+#ifdef HAVE_ID3LIB
+
 #include <qdir.h>
 #include <qstring.h>
+#include "qtcompatmac.h"
+#if QT_VERSION >= 0x040000
+#include <Q3ListBox>
+#include <Q3CString>
+#else
 #include <qlistbox.h>
+#endif
 
 #include <id3/tag.h>
 #ifdef WIN32
-#include <id3.h> /* ID3TagIterator_Delete() */
+#include <id3.h>
 #endif
 
 #include "standardtags.h"
 #include "mp3framelist.h"
 #include "genres.h"
-#include "mp3file.h"
 #include <sys/stat.h>
 #ifdef WIN32
 #include <sys/utime.h>
@@ -75,7 +82,7 @@ Mp3File::~Mp3File(void)
 
 void Mp3File::readTags(bool force)
 {
-	QCString fn = QFile::encodeName(dirname + QDir::separator() + filename);
+	Q3CString fn = QFile::encodeName(dirname + QDir::separator() + filename);
 
 	if (force && tagV1) {
 		tagV1->Clear();
@@ -128,7 +135,7 @@ bool Mp3File::writeTags(bool force, bool *renamed, bool preserve)
 	}
 
 	// store time stamp if it has to be preserved
-	QCString fn;
+	Q3CString fn;
 	bool setUtime = false;
 	struct utimbuf times;
 	if (preserve) {
@@ -261,12 +268,18 @@ QString Mp3File::getString(ID3_Field* field)
 					// In the hope that my patches will be included, I try here
 					// to work around these bugs.
 					uint i;
+					uint numZeroes = 0;
 					for (i = 0; i < unicode_size; i++) {
 						qcarray[i] =
 							UNICODE_SUPPORT_BUGGY ?
 							(ushort)(((txt[i] & 0x00ff) << 8) |
 									 ((txt[i] & 0xff00) >> 8)) :
 							(ushort)txt[i];
+						if (qcarray[i].isNull()) { ++numZeroes; }
+					}
+					// remove a single trailing zero character
+					if (numZeroes == 1 && qcarray[unicode_size - 1].isNull()) {
+						--unicode_size;
 					}
 					text = QString(qcarray, unicode_size);
 					delete [] qcarray;
@@ -365,6 +378,11 @@ int Mp3File::getGenreNum(const ID3_Tag *tag)
 		if (!ok || n > 0xff) {
 			n = 0xff;
 		}
+	} else {
+		// ID3v2 genres can be stored as "(9)", "(9)Metal" or "Metal".
+		// If the string does not start with '(', try to get the genre number
+		// from a string containing a genre text.
+		n = Genres::getNumber(str);
 	}
 	return n;
 }
@@ -406,10 +424,11 @@ void Mp3File::setString(ID3_Field* field, const QString &text)
 			field->Set(unicode);
 			delete [] unicode;
 		}
+	} else if (enc == ID3TE_UTF8) {
+		field->Set(text.utf8().data());
 	} else {
-		// (ID3TE_IS_SINGLE_BYTE_ENC(enc))
-		// (enc == ID3TE_ISO8859_1 || enc == ID3TE_UTF8)
-		field->Set(text);
+		// enc == ID3TE_ISO8859_1
+		field->Set(text.latin1());
 	}
 }
 
@@ -1116,6 +1135,42 @@ QString Mp3File::getFileExtension() const
 	return ".mp3";
 }
 
+/**
+ * Get the format of tag 1.
+ *
+ * @return string describing format of tag 1,
+ *         e.g. "ID3v1.1".
+ */
+QString Mp3File::getTagFormatV1() const
+{
+	return hasTagV1() ? QString("ID3v1.1") : QString::null;
+}
+
+/**
+ * Get the format of tag 2.
+ *
+ * @return string describing format of tag 2,
+ *         e.g. "ID3v2.3", "ID3v2.4".
+ */
+QString Mp3File::getTagFormatV2() const
+{
+	if (tagV2 && tagV2->HasV2Tag()) {
+		switch (tagV2->GetSpec()) {
+			case ID3V2_3_0:
+				return "ID3v2.3.0";
+			case ID3V2_4_0:
+				return "ID3v2.4.0";
+			case ID3V2_2_0:
+				return "ID3v2.2.0";
+			case ID3V2_2_1:
+				return "ID3v2.2.1";
+			default:
+				break;
+		}
+	}
+	return QString::null;
+}
+
 /**
  * Clean up static resources.
  */
@@ -1124,3 +1179,5 @@ void Mp3File::staticCleanup()
 	delete s_mp3FrameList;
 	s_mp3FrameList = 0;
 }
+
+#endif // HAVE_ID3LIB
