@@ -10,26 +10,34 @@
 #ifndef MP3FRAMELIST_H
 #define MP3FRAMELIST_H
 
+#include <qpushbutton.h>
+#include "config.h"
+#ifdef HAVE_ID3LIB
+
 #include "framelist.h"
 
-#if QT_VERSION < 300
-#include <qlist.h>
-#define QPtrList QList
+#include "qtcompatmac.h"
+#if QT_VERSION >= 0x040000
+#include <Q3PtrList>
 #else
 #include <qptrlist.h>
 #endif
-#include <qpushbutton.h>
 #include <id3/tag.h>
 
 class Mp3File;
 class IntComboBoxControl;
 class TextFieldControl;
+class QHBoxLayout;
+class QLabel;
+
+#endif // HAVE_ID3LIB
 
 /** Row of buttons to load, save and view binary data */
 class BinaryOpenSave : public QWidget {
  Q_OBJECT
 
  public:
+#ifdef HAVE_ID3LIB
 	/**
 	 * Constructor.
 	 *
@@ -52,6 +60,7 @@ class BinaryOpenSave : public QWidget {
 	 * @return filename.
 	 */
 	QString getFilename(void) { return loadfilename; }
+#endif // HAVE_ID3LIB
  
  public slots:
  	/**
@@ -71,6 +80,7 @@ class BinaryOpenSave : public QWidget {
 	void viewData(void);
 
  private:
+#ifdef HAVE_ID3LIB
 	/** ID3 field containing binary data */
 	ID3_Field *field;
 	/** horizontal layout */
@@ -85,8 +95,10 @@ class BinaryOpenSave : public QWidget {
 	QPushButton *saveButton;
 	/** View push button */
 	QPushButton *viewButton;
+#endif // HAVE_ID3LIB
 };
 
+#ifdef HAVE_ID3LIB
 
 /**
  * List of ID3v2.3 frames.
@@ -154,6 +166,9 @@ public:
 	friend class TextFieldControl;   // access to getSelectedEncoding()
 
  private:
+	Mp3FrameList(const Mp3FrameList&);
+	Mp3FrameList& operator=(const Mp3FrameList&);
+
 	/**
 	 * Set encoding selected in frame dialog.
 	 *
@@ -208,7 +223,7 @@ public:
 	/** ID3v2 tags containing frames */
 	ID3_Tag *tags;
 	/** List with controls to edit fields in frame */
-	QPtrList<FieldControl> fieldcontrols; 
+	Q3PtrList<FieldControl> fieldcontrols; 
 	/** Number of possible frame IDs */
 #if defined _WIN32 || defined WIN32
 	enum { num_frameid = 76 };
@@ -226,4 +241,6 @@ public:
 	static const ID3_FrameID frameid_code[num_frameid];
 };
 
+#endif // HAVE_ID3LIB
+
 #endif // MP3FRAMELIST_H
