@@ -10,23 +10,23 @@
 #include "musicbrainzdialog.h"
 #ifdef HAVE_TUNEPIMP
 
-#ifdef CONFIG_USE_KDE
-#include <klocale.h>
-#else
-#define i18n(s) tr(s)
-#define I18N_NOOP(s) QT_TR_NOOP(s)
-#endif
-
 #include <qlayout.h>
-#include <qhbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
 #include <qcombobox.h>
 #include <qcheckbox.h>
-#include <qtable.h>
 #include <qlabel.h>
 #include <qtimer.h>
-#include "musicbrainzconfig.h"
+#if QT_VERSION >= 0x040000
+#include <q3hbox.h>
+#include <q3table.h>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
+#else
+#include <qhbox.h>
+#include <qtable.h>
+#endif
+#include "kid3.h"
 #include "musicbrainzclient.h"
 
 /**
@@ -58,41 +58,27 @@ MusicBrainzDialog::MusicBrainzDialog(QWidget* parent,
 			"nl.musicbrainz.org:80",
 			0                  // end of StrList
 		};
-		m_serverComboBox->insertStrList(serverList);
-#if QT_VERSION >= 0x030100
-		m_serverComboBox->setSizePolicy(
-			QSizePolicy::Expanding, QSizePolicy::Minimum);
-#else
+		QStringList strList;
+		for (const char** sl = serverList; *sl != 0; ++sl) {
+			strList += *sl;
+		}
+		m_serverComboBox->QCM_addItems(strList);
 		m_serverComboBox->setSizePolicy(
 			QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
-#endif
 		serverLabel->setBuddy(m_serverComboBox);
 		serverLayout->addWidget(serverLabel);
 		serverLayout->addWidget(m_serverComboBox);
 		connect(m_serverComboBox, SIGNAL(activated(int)),
 						this, SLOT(setClientConfig()));
 	}
-	QHBoxLayout* proxyLayout = new QHBoxLayout(vlayout);
-	m_proxyCheckBox = new QCheckBox(i18n("&Proxy:"), this);
-	m_proxyLineEdit = new QLineEdit(this);
-	if (proxyLayout && m_proxyCheckBox && m_proxyLineEdit) {
-		proxyLayout->addWidget(m_proxyCheckBox);
-		proxyLayout->addWidget(m_proxyLineEdit);
-		connect(m_proxyCheckBox, SIGNAL(toggled(bool)),
-						this, SLOT(setClientConfig()));
-		connect(m_proxyLineEdit, SIGNAL(returnPressed()),
-						this, SLOT(setClientConfig()));
-	}
-	m_albumTable = new QTable(this, "albumTable");
+	m_albumTable = new Q3Table(this, "albumTable");
 	if (m_albumTable) {
 		m_albumTable->setNumCols(2);
-#if QT_VERSION >= 300
 		m_albumTable->setColumnReadOnly(1, true);
-		m_albumTable->setFocusStyle(QTable::FollowStyle);
-#endif
+		m_albumTable->setFocusStyle(Q3Table::FollowStyle);
 		m_albumTable->setColumnStretchable(0, true);
-		m_albumTable->setSelectionMode(QTable::NoSelection);
-		QHeader* hHeader = m_albumTable->horizontalHeader();
+		m_albumTable->setSelectionMode(Q3Table::NoSelection);
+		Q3Header* hHeader = m_albumTable->horizontalHeader();
 		hHeader->setLabel(0, "08 A Not So Short Title/Medium Sized Artist - And The Album Title [2005]");
 		hHeader->setLabel(1, "A Not So Short State");
 		m_albumTable->adjustColumn(0);
@@ -106,19 +92,26 @@ MusicBrainzDialog::MusicBrainzDialog(QWidget* parent,
 	QHBoxLayout *hlayout = new QHBoxLayout(vlayout);
 	QSpacerItem *hspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
 	                                       QSizePolicy::Minimum);
+	QPushButton* helpButton = new QPushButton(i18n("&Help"), this);
+	QPushButton* saveButton = new QPushButton(i18n("&Save Settings"), this);
 	QPushButton* okButton = new QPushButton(i18n("&OK"), this);
 	QPushButton* applyButton = new QPushButton(i18n("&Apply"), this);
 	QPushButton* cancelButton = new QPushButton(i18n("&Cancel"), this);
-	if (hlayout && okButton && cancelButton && applyButton) {
+	if (hlayout && helpButton && saveButton &&
+			okButton && cancelButton && applyButton) {
+		hlayout->addWidget(helpButton);
+		hlayout->addWidget(saveButton);
 		hlayout->addItem(hspacer);
 		hlayout->addWidget(okButton);
 		hlayout->addWidget(applyButton);
 		hlayout->addWidget(cancelButton);
 		// auto default is switched off to use the return key to set the server
-		// and proxy configuration
+		// configuration
 		okButton->setAutoDefault(false);
 		cancelButton->setAutoDefault(false);
 		applyButton->setAutoDefault(false);
+		connect(helpButton, SIGNAL(clicked()), this, SLOT(showHelp()));
+		connect(saveButton, SIGNAL(clicked()), this, SLOT(saveConfig()));
 		connect(okButton, SIGNAL(clicked()), this, SLOT(accept()));
 		connect(cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
 		connect(applyButton, SIGNAL(clicked()), this, SLOT(apply()));
@@ -139,22 +132,16 @@ MusicBrainzDialog::~MusicBrainzDialog()
  */
 void MusicBrainzDialog::initTable()
 {
-#if QT_VERSION >= 300
+	setServer(Kid3App::s_musicBrainzCfg.m_server);
+
 	unsigned numRows = m_trackDataVector.size();
-#else
-	unsigned numRows = m_trackDataVector.count();
-#endif
 	m_trackResults.resize(numRows);
 	m_albumTable->setNumRows(numRows);
 	for (unsigned i = 0; i < numRows; ++i) {
-#if QT_VERSION >= 300
-		QComboTableItem* cti = new QComboTableItem(
+		Q3ComboTableItem* cti = new Q3ComboTableItem(
 			m_albumTable, QStringList(i18n("No result")));
 		m_albumTable->setItem(i, 0, cti);
 		m_albumTable->setText(i, 1, i18n("Unknown"));
-#else
-		m_albumTable->setText(i, 0, i18n("Unknown"));
-#endif
 	}
 }
 
@@ -163,11 +150,7 @@ void MusicBrainzDialog::initTable()
  */
 void MusicBrainzDialog::clearResults()
 {
-#if QT_VERSION >= 300
 	unsigned numRows = m_trackDataVector.size();
-#else
-	unsigned numRows = m_trackDataVector.count();
-#endif
 	for (unsigned i = 0; i < numRows; ++i) {
 		m_trackResults[i].clear();
 		setFileStatus(i, i18n("Unknown"));
@@ -181,9 +164,9 @@ void MusicBrainzDialog::clearResults()
 void MusicBrainzDialog::setClientConfig()
 {
 	if (m_client) {
-		MusicBrainzConfig cfg;
-		getMusicBrainzConfig(&cfg);
-		m_client->setMusicBrainzConfig(&cfg);
+		m_client->setConfig(
+			getServer(),
+			Kid3App::s_miscCfg.m_proxy, Kid3App::s_miscCfg.m_useProxy);
 	}
 }
 
@@ -254,11 +237,10 @@ void MusicBrainzDialog::reject()
 void MusicBrainzDialog::apply()
 {
 	bool newTrackData = false;
-#if QT_VERSION >= 300
 	unsigned numRows = m_trackDataVector.size();
 	for (unsigned index = 0; index < numRows; ++index) {
-		QComboTableItem* item =
-			dynamic_cast<QComboTableItem*>(m_albumTable->item(index, 0));
+		Q3ComboTableItem* item =
+			dynamic_cast<Q3ComboTableItem*>(m_albumTable->item(index, 0));
 		if (item) {
 			int selectedItem = item->currentItem();
 			if (selectedItem > 0) {
@@ -275,21 +257,6 @@ void MusicBrainzDialog::apply()
 			}
 		}
 	}
-#else
-	unsigned numRows = m_trackDataVector.count();
-	for (unsigned index = 0; index < numRows; ++index) {
-		const ImportTrackData& selectedData =
-			m_trackResults[index][0];
-		m_trackDataVector[index].title = selectedData.title;
-		m_trackDataVector[index].artist = selectedData.artist;
-		m_trackDataVector[index].album = selectedData.album;
-		m_trackDataVector[index].track = selectedData.track;
-		m_trackDataVector[index].year = selectedData.year;
-		m_trackDataVector[index].setImportDuration(
-			selectedData.getImportDuration());
-		newTrackData = true;
-	}
-#endif
 	if (newTrackData) {
 		emit trackDataUpdated();
 	}
@@ -334,25 +301,11 @@ void MusicBrainzDialog::setFileStatus(int index, QString status)
 void MusicBrainzDialog::updateFileTrackData(int index)
 {
 	QStringList stringList;
-#if QT_VERSION >= 300
 	unsigned numResults = m_trackResults[index].size();
-#else
-	unsigned numResults = m_trackResults[index].count();
-#endif
 	QString str(numResults == 0 ?
 							i18n("No result") : i18n("No result selected"));
-#if QT_VERSION >= 300
 	stringList.push_back(str);
-#else
-	stringList.append(str);
-#endif
-	for (
-#if QT_VERSION >= 300
-		ImportTrackDataVector::const_iterator
-#else
-		ImportTrackDataVector::ConstIterator
-#endif
-			 it = m_trackResults[index].begin();
+	for (ImportTrackDataVector::const_iterator it = m_trackResults[index].begin();
 			 it != m_trackResults[index].end();
 			 ++it) {
 		str.sprintf("%02d ", (*it).track);
@@ -364,15 +317,10 @@ void MusicBrainzDialog::updateFileTrackData(int index)
 		if ((*it).year > 0) {
 			str += QString(" [%1]").arg((*it).year);
 		}
-#if QT_VERSION >= 300
 		stringList.push_back(str);
-#else
-		stringList.append(str);
-#endif
 	}
-#if QT_VERSION >= 300
-	QComboTableItem* item =
-		dynamic_cast<QComboTableItem*>(m_albumTable->item(index, 0));
+	Q3ComboTableItem* item =
+		dynamic_cast<Q3ComboTableItem*>(m_albumTable->item(index, 0));
 	if (item) {
 		item->setStringList(stringList);
 		// if there is only one result, select it, else let the user select
@@ -380,9 +328,6 @@ void MusicBrainzDialog::updateFileTrackData(int index)
 			item->setCurrentItem(1);
 		}
 	}
-#else
-	m_albumTable->setText(index, 0, stringList.first());
-#endif
 }
 
 /**
@@ -394,11 +339,7 @@ void MusicBrainzDialog::updateFileTrackData(int index)
 void MusicBrainzDialog::setMetaData(int index, ImportTrackData& trackData)
 {
 	m_trackResults[index].clear();
-#if QT_VERSION >= 300
 	m_trackResults[index].push_back(trackData);
-#else
-	m_trackResults[index].append(trackData);
-#endif
 	updateFileTrackData(index);
 }
 
@@ -414,11 +355,7 @@ void MusicBrainzDialog::setResults(
 	m_trackResults[index] = trackDataVector;
 	updateFileTrackData(index);
 	for (
-#if QT_VERSION >= 300
 		 ImportTrackDataVector::const_iterator
-#else
-		 ImportTrackDataVector::ConstIterator
-#endif
 			 it = trackDataVector.begin();
 			 it != trackDataVector.end();
 			 ++it) {
@@ -446,58 +383,23 @@ QString MusicBrainzDialog::getServer() const
  */
 void MusicBrainzDialog::setServer(const QString& srv)
 {
-#if QT_VERSION >= 300
 	m_serverComboBox->setCurrentText(srv);
-#else
-	m_serverComboBox->setEditText(srv);
-#endif
 }
 
 /**
- * Get proxy.
- *
- * @param used is set to true if proxy is used
- *
- * @return proxy, e.g. "myproxy:8080".
+ * Save the local settings to the configuration.
  */
-QString MusicBrainzDialog::getProxy(bool* used) const
+void MusicBrainzDialog::saveConfig()
 {
-	*used = m_proxyCheckBox->isChecked();
-	return m_proxyLineEdit->text();
+	Kid3App::s_musicBrainzCfg.m_server = getServer();
 }
 
 /**
- * Set proxy.
- *
- * @param proxy proxy, e.g. "myproxy:8080"
- * @param used is set to true if proxy is used
+ * Show help.
  */
-void MusicBrainzDialog::setProxy(const QString& proxy, bool used)
+void MusicBrainzDialog::showHelp()
 {
-	m_proxyCheckBox->setChecked(used);
-	m_proxyLineEdit->setText(proxy);
-}
-
-/**
- * Set MusicBrainz configuration.
- *
- * @param cfg MusicBrainz configuration.
- */
-void MusicBrainzDialog::setMusicBrainzConfig(const MusicBrainzConfig* cfg)
-{
-	setProxy(cfg->m_proxy, cfg->m_useProxy);
-	setServer(cfg->m_server);
-}
-
-/**
- * Get musicBrainz.org configuration.
- *
- * @param cfg musicBrainz configuration.
- */
-void MusicBrainzDialog::getMusicBrainzConfig(MusicBrainzConfig* cfg) const
-{
-	cfg->m_proxy = getProxy(&cfg->m_useProxy);
-	cfg->m_server = getServer();
+	Kid3App::displayHelp("import-musicbrainz");
 }
 
 #else // HAVE_TUNEPIMP
@@ -514,5 +416,7 @@ void MusicBrainzDialog::setFileStatus(int, QString) {}
 void MusicBrainzDialog::updateFileTrackData(int) {}
 void MusicBrainzDialog::setMetaData(int, ImportTrackData&) {}
 void MusicBrainzDialog::setResults(int, ImportTrackDataVector&) {}
+void MusicBrainzDialog::saveConfig() {}
+void MusicBrainzDialog::showHelp() {}
 
 #endif // HAVE_TUNEPIMP
