@@ -15,17 +15,18 @@
 #include "importtrackdata.h"
 #include <qdialog.h>
 #include <qstring.h>
-#if QT_VERSION >= 300
-#include <qvaluevector.h>
+#include "qtcompatmac.h"
+#if QT_VERSION >= 0x040000
+#include <Q3ValueVector>
 #else
-#include <qvaluelist.h>
+#include <qvaluevector.h>
 #endif
 
 class QLineEdit;
 class QComboBox;
 class QPushButton;
 class QCheckBox;
-class QTable;
+class Q3Table;
 class QTimer;
 class MusicBrainzConfig;
 class MusicBrainzClient;
@@ -71,37 +72,6 @@ public:
 	 * @param srv "servername:port"
 	 */
 	void setServer(const QString& srv);
-
-	/**
-	 * Get proxy.
-	 *
-	 * @param used is set to true if proxy is used
-	 *
-	 * @return proxy, e.g. "myproxy:8080".
-	 */
-	QString getProxy(bool* used) const;
-
-	/**
-	 * Set proxy.
-	 *
-	 * @param proxy proxy, e.g. "myproxy:8080"
-	 * @param used is set to true if proxy is used
-	 */
-	void setProxy(const QString& proxy, bool used);
-
-	/**
-	 * Set MusicBrainz configuration.
-	 *
-	 * @param cfg MusicBrainz configuration.
-	 */
-	void setMusicBrainzConfig(const MusicBrainzConfig* cfg);
-
-	/**
-	 * Get MusicBrainz configuration.
-	 *
-	 * @param cfg MusicBrainz configuration.
-	 */
-	void getMusicBrainzConfig(MusicBrainzConfig* cfg) const;
 #endif // HAVE_TUNEPIMP
 
 signals:
@@ -175,6 +145,16 @@ private slots:
 	 */
 	void setResults(int index, ImportTrackDataVector& trackDataVector);
 
+	/**
+	 * Save the local settings to the configuration.
+	 */
+	void saveConfig();
+
+	/**
+	 * Show help.
+	 */
+	void showHelp();
+
 #ifdef HAVE_TUNEPIMP
 private:
 	/**
@@ -193,17 +173,11 @@ private:
 	void stopClient();
 
 	QComboBox* m_serverComboBox;
-	QCheckBox* m_proxyCheckBox;
-	QLineEdit* m_proxyLineEdit;
-	QTable* m_albumTable;
+	Q3Table* m_albumTable;
 	QTimer* m_timer;
 	MusicBrainzClient* m_client;
 	ImportTrackDataVector& m_trackDataVector;
-#if QT_VERSION >= 300
-	QValueVector<ImportTrackDataVector> m_trackResults;
-#else
-	QValueList<ImportTrackDataVector> m_trackResults;
-#endif
+	Q3ValueVector<ImportTrackDataVector> m_trackResults;
 #endif // HAVE_TUNEPIMP
 };
 
