@@ -19,6 +19,7 @@ class QComboBox;
  * Number tracks dialog.
  */
 class NumberTracksDialog : public QDialog {
+Q_OBJECT
 public:
 	/**
 	 * Constructor.
@@ -45,6 +46,12 @@ public:
 	 */
 	bool getDestV1() const;
 
+private slots:
+	/**
+	 * Show help.
+	 */
+	void showHelp();
+
 private:
 	/** Destinations */
 	enum Destination { DestV1, DestV2 };
