@@ -15,6 +15,9 @@
 #include "oggframelist.h"
 #include <qfile.h>
 #include <qdir.h>
+#if QT_VERSION >= 0x040000
+#include <Q3CString>
+#endif
 #include <sys/stat.h>
 #ifdef WIN32
 #include <sys/utime.h>
@@ -58,7 +61,7 @@ void OggFile::readTags(bool force)
 		m_comments.clear();
 		changedV2 = false;
 		m_fileRead = true;
-		QCString fnIn = QFile::encodeName(dirname + QDir::separator() + filename);
+		Q3CString fnIn = QFile::encodeName(dirname + QDir::separator() + filename);
 
 		if (m_fileInfo.read(fnIn)) {
 			FILE* fpIn = ::fopen(fnIn, "rb");
@@ -79,12 +82,7 @@ void OggFile::readTags(bool force)
 									QString value(
 										userComment.mid(equalPos + 1).stripWhiteSpace());
 									if (!value.isEmpty()) {
-#if QT_VERSION >= 300
-										m_comments.push_back(
-#else
-										m_comments.append(
-#endif
-											CommentField(name, value));
+										m_comments.push_back(CommentField(name, value));
 									}
 								}
 							}
@@ -123,7 +121,7 @@ bool OggFile::writeTags(bool force, bool* renamed, bool preserve)
 	if (m_fileRead && (force || changedV2)) {
 		bool writeOk = false;
 		QString tempFilename(filename);
-		QCString fnIn;
+		Q3CString fnIn;
 		if (new_filename == filename) {
 			// we have to rename the original file and delete it afterwards
 			tempFilename += "_KID3";
@@ -134,7 +132,7 @@ bool OggFile::writeTags(bool force, bool* renamed, bool preserve)
 		} else {
 			fnIn = QFile::encodeName(dirname + QDir::separator() + filename);
 		}
-		QCString fnOut = QFile::encodeName(dirname + QDir::separator() +
+		Q3CString fnOut = QFile::encodeName(dirname + QDir::separator() +
 																			 new_filename);
 		FILE* fpIn = ::fopen(fnIn, "rb");
 		if (fpIn) {
@@ -143,7 +141,7 @@ bool OggFile::writeTags(bool force, bool* renamed, bool preserve)
 			bool setUtime = false;
 			struct utimbuf times;
 			if (preserve) {
-				int fd = ::fileno(fpIn);
+				int fd = fileno(fpIn);
 				if (fd >= 0) {
 					struct stat fileStat;
 					if (::fstat(fd, &fileStat) == 0) {
@@ -163,11 +161,7 @@ bool OggFile::writeTags(bool force, bool* renamed, bool preserve)
 						if (vc) {
 							::vorbis_comment_clear(vc);
 							::vorbis_comment_init(vc);
-#if QT_VERSION >= 300
 							CommentList::iterator it = m_comments.begin();
-#else
-							CommentList::Iterator it = m_comments.begin();
-#endif
 							while (it != m_comments.end()) {
 								QString name((*it).getName());
 								QString value((*it).getValue());
@@ -178,11 +172,7 @@ bool OggFile::writeTags(bool force, bool* renamed, bool preserve)
 										const_cast<char*>((const char*)value.utf8()));
 									++it;
 								} else {
-#if QT_VERSION >= 300
 									it = m_comments.erase(it);
-#else
-									it = m_comments.remove(it);
-#endif
 								}
 							}
 							if (::vcedit_write(state, fpOut) >= 0) {
@@ -506,11 +496,7 @@ bool OggFile::isTagInformationRead() const
  */
 bool OggFile::hasTagV2() const
 {
-#if QT_VERSION >= 300
 	return !m_comments.empty();
-#else
-	return m_comments.count() > 0;
-#endif
 }
 
 /**
@@ -559,6 +545,16 @@ unsigned OggFile::getDuration() const
 	return 0;
 }
 
+/**
+ * Get the format of tag 2.
+ *
+ * @return "Vorbis".
+ */
+QString OggFile::getTagFormatV2() const
+{
+	return hasTagV2() ? QString("Vorbis") : QString::null;
+}
+
 /** Frame list for Ogg files. */
 OggFrameList* OggFile::s_oggFrameList = 0;
 
@@ -637,13 +633,7 @@ void OggFile::staticCleanup() {}
  */
 QString OggFile::CommentList::getValue(const QString& name) const
 {
-	for (
-#if QT_VERSION >= 300
-		const_iterator
-#else
-		ConstIterator
-#endif
-		it = begin(); it != end(); ++it) {
+	for (const_iterator it = begin(); it != end(); ++it) {
 		if ((*it).getName() == name) {
 			return (*it).getValue();
 		}
@@ -659,13 +649,7 @@ QString OggFile::CommentList::getValue(const QString& name) const
  */
 bool OggFile::CommentList::setValue(const QString& name, const QString& value)
 {
-	for (
-#if QT_VERSION >= 300
-		iterator
-#else
-		Iterator
-#endif
-		it = begin(); it != end(); ++it) {
+	for (iterator it = begin(); it != end(); ++it) {
 		if ((*it).getName() == name) {
 			QString oldValue = (*it).getValue();
 			if (value != oldValue) {
@@ -678,11 +662,7 @@ bool OggFile::CommentList::setValue(const QString& name, const QString& value)
 	}
 	if (!value.isEmpty()) {
 		CommentField cf(name, value);
-#if QT_VERSION >= 300
 		push_back(cf);
-#else
-		append(cf);
-#endif
 		return true;
 	} else {
 		return false;
