@@ -9,17 +9,19 @@
 
 #include "oggframelist.h"
 #if defined HAVE_VORBIS || defined HAVE_FLAC
-#ifdef CONFIG_USE_KDE
-#include <klocale.h>
-#else
-#define i18n(s) tr(s)
-#define I18N_NOOP(s) QT_TR_NOOP(s)
-#endif
 
 #include <qdialog.h>
 #include <qpushbutton.h>
 #include <qinputdialog.h>
 #include <qstringlist.h>
+#include "qtcompatmac.h"
+#if QT_VERSION >= 0x040000
+#include <Q3ListBox>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
+#else
+#include <qlistbox.h>
+#endif
 
 /** Field edit dialog */
 class EditOggFrameDialog : public QDialog {
@@ -76,9 +78,7 @@ EditOggFrameDialog::EditOggFrameDialog(QWidget* parent, const QString& caption,
 		m_edit = new QTextEdit(this);
 		if (m_edit) {
 			m_edit->setText(text);
-#if QT_VERSION >= 300
 			m_edit->moveCursor(QTextEdit::MoveEnd, false);
-#endif
 			vlayout->addWidget(m_edit);
 		}
 	}
@@ -95,7 +95,10 @@ EditOggFrameDialog::EditOggFrameDialog(QWidget* parent, const QString& caption,
 		connect(m_okButton, SIGNAL(clicked()), this, SLOT(accept()));
 		connect(m_cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
 	}
+#if QT_VERSION < 0x040000
+	// the widget is not painted correctly after resizing in Qt4
 	resize(fontMetrics().maxWidth() * 30, -1);
+#endif
 }
 
 /**
@@ -128,13 +131,7 @@ void OggFrameList::readTags()
 {
 	listbox->clear();
 	if (m_tags) {
-		for (
-#if QT_VERSION >= 300
-			OggFile::CommentList::const_iterator
-#else
-			OggFile::CommentList::ConstIterator
-#endif
-				 it = m_tags->begin();
+		for (OggFile::CommentList::const_iterator it = m_tags->begin();
 				 it != m_tags->end();
 				 ++it) {
 			listbox->insertItem((*it).getName());
@@ -191,13 +188,7 @@ bool OggFrameList::editFrame()
 {
 	int selectedIndex = listbox->currentItem();
 	if (selectedIndex != -1 && m_tags) {
-#if QT_VERSION >= 300
-		OggFile::CommentList::iterator
-#else
-		OggFile::CommentList::Iterator
-#endif
-			it = m_tags->at(selectedIndex);
-
+		OggFile::CommentList::iterator it = m_tags->at(selectedIndex);
 		return editFrame(*it);
 	}
 	return false;
@@ -212,13 +203,8 @@ bool OggFrameList::deleteFrame()
 {
 	int selectedIndex = listbox->currentItem();
 	if (selectedIndex != -1 && m_tags) {
-#if QT_VERSION >= 300
 		OggFile::CommentList::iterator it = m_tags->at(selectedIndex);
 		m_tags->erase(it);
-#else
-		OggFile::CommentList::Iterator it = m_tags->at(selectedIndex);
-		m_tags->remove(it);
-#endif
 		readTags(); // refresh listbox
 		// select the next item (or the last if it was the last)
 		if (selectedIndex >= 0) {
@@ -253,11 +239,7 @@ bool OggFrameList::addFrame(int frameId, bool edit)
 		if (edit && !editFrame(frame)) {
 			return false;
 		}
-#if QT_VERSION >= 300
 		m_tags->push_back(frame);
-#else
-		m_tags->append(frame);
-#endif
 		readTags(); // refresh listbox
 		const int lastIndex = listbox->count() - 1;
 		if (lastIndex >= 0) {
@@ -355,12 +337,7 @@ int OggFrameList::selectFrameId()
 bool OggFrameList::copyFrame() {
 	int selectedIndex = listbox->currentItem();
 	if (selectedIndex != -1 && m_tags) {
-#if QT_VERSION >= 300
-		OggFile::CommentList::iterator
-#else
-		OggFile::CommentList::Iterator
-#endif
-			it = m_tags->at(selectedIndex);
+		OggFile::CommentList::iterator it = m_tags->at(selectedIndex);
 		if (it != m_tags->end()) {
 			m_copyFrame = *it;
 		}
@@ -377,11 +354,7 @@ bool OggFrameList::copyFrame() {
 bool OggFrameList::pasteFrame() {
 	if (!(m_copyFrame.getName().isEmpty() && m_copyFrame.getValue().isEmpty()) &&
 			m_tags) {
-#if QT_VERSION >= 300
 		m_tags->push_back(m_copyFrame);
-#else
-		m_tags->append(m_copyFrame);
-#endif
 		if (m_file) {
 			m_file->changedV2 = true;
 		}
