@@ -7,23 +7,24 @@
  * \date 21 Mar 2004
  */
 
-#include "config.h"
-#ifdef CONFIG_USE_KDE
-#include <klocale.h>
-#else
-#define i18n(s) tr(s)
-#define I18N_NOOP(s) QT_TR_NOOP(s)
-#endif
-
 #include <qlayout.h>
-#include <qhbox.h>
 #include <qpushbutton.h>
 #include <qcombobox.h>
 #include <qlabel.h>
 #include <qdir.h>
+#include "qtcompatmac.h"
+#if QT_VERSION >= 0x040000
+#include <Q3HBox>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
+#include <QGridLayout>
+#else
+#include <qhbox.h>
+#endif
 
 #include "taggedfile.h"
 #include "standardtags.h"
+#include "kid3.h"
 #include "miscconfig.h"
 #include "rendirdialog.h"
 
@@ -33,12 +34,9 @@
  * @param parent     parent widget
  * @param caption    dialog title
  * @param taggedFile file to use for rename preview
- * @param formatItem directory format item
- * @param formatText directory format
  */
 RenDirDialog::RenDirDialog(QWidget *parent, const QString &caption,
-						   TaggedFile *taggedFile,
-						   int formatItem, const QString &formatText) :
+						   TaggedFile *taggedFile) :
 	QDialog(parent, "rendir", true), m_taggedFile(taggedFile)
 {
 	setCaption(caption);
@@ -58,8 +56,8 @@ RenDirDialog::RenDirDialog(QWidget *parent, const QString &caption,
 		actionComboBox->insertItem(i18n("Create Directory"), ActionCreate);
 		actionLayout->addWidget(actionComboBox);
 		connect(actionComboBox, SIGNAL(activated(int)), this, SLOT(slotUpdateNewDirname()));
-		tagversionComboBox->insertItem(i18n("From ID3v1"), TagV1);
-		tagversionComboBox->insertItem(i18n("From ID3v2"), TagV2);
+		tagversionComboBox->insertItem(i18n("From Tag 1"), TagV1);
+		tagversionComboBox->insertItem(i18n("From Tag 2"), TagV2);
 		actionLayout->addWidget(tagversionComboBox);
 		connect(tagversionComboBox, SIGNAL(activated(int)), this, SLOT(slotUpdateNewDirname()));
 	}
@@ -67,14 +65,16 @@ RenDirDialog::RenDirDialog(QWidget *parent, const QString &caption,
 	QLabel *formatLabel = new QLabel(i18n("&Format:"), this);
 	formatComboBox = new QComboBox(this);
 	if (formatLayout && formatLabel && formatComboBox) {
-		formatComboBox->insertStrList(MiscConfig::defaultDirFmtList);
+		QStringList strList;
+		for (const char** sl = MiscConfig::defaultDirFmtList; *sl != 0; ++sl) {
+			strList += *sl;
+		}
+		formatComboBox->QCM_addItems(strList);
 		formatComboBox->setEditable(true);
-		formatComboBox->setCurrentItem(formatItem);
-#if QT_VERSION >= 300
-		formatComboBox->setCurrentText(formatText);
-#else
-		formatComboBox->setEditText(formatText);
-#endif
+		formatComboBox->setCurrentItem(Kid3App::s_miscCfg.dirFormatItem);
+		formatComboBox->setCurrentText(Kid3App::s_miscCfg.dirFormatText);
+		tagversionComboBox->setCurrentItem(
+			Kid3App::s_miscCfg.m_renDirSrcV1 ? TagV1 : TagV2);
 		formatLabel->setBuddy(formatComboBox);
 		formatLayout->addWidget(formatLabel);
 		formatLayout->addWidget(formatComboBox);
@@ -98,13 +98,19 @@ RenDirDialog::RenDirDialog(QWidget *parent, const QString &caption,
 	QHBoxLayout *hlayout = new QHBoxLayout(vlayout);
 	QSpacerItem *hspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
 	                                       QSizePolicy::Minimum);
+	QPushButton *helpButton = new QPushButton(i18n("&Help"), this);
+	QPushButton *saveButton = new QPushButton(i18n("&Save Settings"), this);
 	QPushButton *okButton = new QPushButton(i18n("&OK"), this);
 	QPushButton *cancelButton = new QPushButton(i18n("&Cancel"), this);
-	if (hlayout && okButton && cancelButton) {
+	if (hlayout && helpButton && saveButton && okButton && cancelButton) {
+		hlayout->addWidget(helpButton);
+		hlayout->addWidget(saveButton);
 		hlayout->addItem(hspacer);
 		hlayout->addWidget(okButton);
 		hlayout->addWidget(cancelButton);
 		okButton->setDefault(TRUE);
+		connect(helpButton, SIGNAL(clicked()), this, SLOT(showHelp()));
+		connect(saveButton, SIGNAL(clicked()), this, SLOT(saveConfig()));
 		connect(okButton, SIGNAL(clicked()), this, SLOT(accept()));
 		connect(cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
 	}
@@ -252,13 +258,7 @@ QString RenDirDialog::generateNewDirname(TaggedFile *taggedFile, QString *olddir
 		taggedFile->getStandardTagsV2(&st);
 	}
 	QString newdir(taggedFile->getDirname());
-	if (
-#if QT_VERSION >= 300
-		newdir.endsWith(QChar('/'))
-#else
-		newdir.at(newdir.length() - 1) == '/'
-#endif
-	   ) {
+	if (newdir.endsWith(QChar('/'))) {
 		// remove trailing separator
 		newdir.truncate(newdir.length() - 1);
 	}
@@ -398,21 +398,20 @@ bool RenDirDialog::performAction(TaggedFile *taggedFile, bool& again, QString *e
 }
 
 /**
- * Get currently selected directory format item.
- *
- * @return index of directory format.
+ * Save the local settings to the configuration.
  */
-int RenDirDialog::getFormatItem(void) const
+void RenDirDialog::saveConfig()
 {
-	return formatComboBox->currentItem();
+	Kid3App::s_miscCfg.dirFormatItem = formatComboBox->currentItem();
+	Kid3App::s_miscCfg.dirFormatText = formatComboBox->currentText();
+	Kid3App::s_miscCfg.m_renDirSrcV1 =
+		(tagversionComboBox->currentItem() == TagV1);
 }
 
 /**
- * Get currently used directory format.
- *
- * @return directory format.
+ * Show help.
  */
-QString RenDirDialog::getFormatText(void) const
+void RenDirDialog::showHelp()
 {
-	return formatComboBox->currentText();
+	Kid3App::displayHelp("rename-directory");
 }
