@@ -9,248 +9,31 @@
 
 #include <qdir.h>
 #include <qstring.h>
-#include <qlistbox.h>
 #include <qregexp.h>
-#include <qapplication.h>
-#include <qpainter.h>
 
 #include "standardtags.h"
 #include "filelist.h"
-#include "miscconfig.h"
+#include "kid3.h"
 #include "genres.h"
 #include "taggedfile.h"
 
-/** Empty pixmap, will be allocated in constructor */
-QPixmap *TaggedFile::nullPixmap = 0;
-/** Pixmap for modified file, will be allocated in constructor */
-QPixmap *TaggedFile::modifiedPixmap = 0;
-/** Pixmap for V1V2, will be allocated in constructor */
-QPixmap *TaggedFile::v1v2Pixmap = 0;
-/** Pixmap for V1, will be allocated in constructor */
-QPixmap *TaggedFile::v1Pixmap = 0;
-/** Pixmap for V2, will be allocated in constructor */
-QPixmap *TaggedFile::v2Pixmap = 0;
-/** Pixmap for "no tag", will be allocated in constructor */
-QPixmap *TaggedFile::notagPixmap = 0;
-
-/* The bitmaps are stored here instead of using KDE bitmaps to make
-   it work for the Qt only versions. */
-/** picture for modified pixmap */
-static const char * const modified_xpm[] = {
-	"16 16 33 1",
-	". c None",
-	"B c None",
-	"A c None",
-	"C c None",
-	"D c None",
-	"E c None",
-	"# c #000000",
-	"b c #006562",
-	"j c #414041",
-	"x c #525552",
-	"f c #529594",
-	"e c #52959c",
-	"w c #5a555a",
-	"v c #626162",
-	"u c #626562",
-	"r c #737173",
-	"p c #737573",
-	"q c #7b757b",
-	"o c #838183",
-	"m c #838583",
-	"z c #8b8d8b",
-	"l c #949194",
-	"k c #9c959c",
-	"i c #a4a1a4",
-	"h c #a4a5a4",
-	"y c #b4b6b4",
-	"g c #bdb6bd",
-	"a c #c5c2c5",
-	"s c #c5c6c5",
-	"c c #cdc6cd",
-	"t c #dedade",
-	"n c #eeeaee",
-	"d c #ffffff",
-	".......##.......",
-	"......#ab#......",
-	".....#cbde#.....",
-	"....#abdddf#....",
-	"...#gbddddde#...",
-	"..#hijddddddf#..",
-	".#kjkljdddddd##.",
-	"#mjnjmojddddjma#",
-	"#jnpnjqrjddjqs#.",
-	"#drtttjuvjjua#..",
-	".#dasajjwxws#...",
-	"..#dyjzljxa#...A",
-	"...#jrrjws#...AB",
-	"....#cjxa#...ACB",
-	".....#cs#...ADE.",
-	"......##...ABB.."
-};
-
-/** picture for empty pixmap */
-static const char * const null_xpm[] = {
-	"16 16 2 1",
-	"# c None",
-	". c None",
-	".#.#.#.#.#.#.#.#",
-	"#.#.#.#.#.#.#.#.",
-	".#.#.#.#.#.#.#.#",
-	"#.#.#.#.#.#.#.#.",
-	".#.#.#.#.#.#.#.#",
-	"#.#.#.#.#.#.#.#.",
-	".#.#.#.#.#.#.#.#",
-	"#.#.#.#.#.#.#.#.",
-	".#.#.#.#.#.#.#.#",
-	"#.#.#.#.#.#.#.#.",
-	".#.#.#.#.#.#.#.#",
-	"#.#.#.#.#.#.#.#.",
-	".#.#.#.#.#.#.#.#",
-	"#.#.#.#.#.#.#.#.",
-	".#.#.#.#.#.#.#.#",
-	"#.#.#.#.#.#.#.#."
-};
-
-/* XPM */
-static const char * const v1v2_xpm[] = {
-	"16 16 3 1",
-	"       c None",
-	".      c #000000",
-	"+      c #FFFFFF",
-	"                ",
-	"                ",
-	"   .   .   .    ",
-	"   .   .  ..    ",
-	"    . .  . .    ",
-	"    . .    .    ",
-	"     .     .    ",
-	"                ",
-	"                ",
-	"   .   .  ..    ",
-	"   .   . .  .   ",
-	"    . .    .    ",
-	"    . .   .     ",
-	"     .   ....   ",
-	"                ",
-	"                "};
-
-/* XPM */
-static const char * const v1_xpm[] = {
-	"16 16 3 1",
-	"       c None",
-	".      c #000000",
-	"+      c #FFFFFF",
-	"                ",
-	"                ",
-	"   .   .   .    ",
-	"   .   .  ..    ",
-	"    . .  . .    ",
-	"    . .    .    ",
-	"     .     .    ",
-	"                ",
-	"                ",
-	"                ",
-	"                ",
-	"                ",
-	"                ",
-	"                ",
-	"                ",
-	"                "};
-
-/* XPM */
-static const char * const v2_xpm[] = {
-	"16 16 3 1",
-	"       c None",
-	".      c #000000",
-	"+      c #FFFFFF",
-	"                ",
-	"                ",
-	"                ",
-	"                ",
-	"                ",
-	"                ",
-	"                ",
-	"                ",
-	"                ",
-	"   .   .  ..    ",
-	"   .   . .  .   ",
-	"    . .    .    ",
-	"    . .   .     ",
-	"     .   ....   ",
-	"                ",
-	"                "};
-
-/* XPM */
-static const char * const notag_xpm[] = {
-	"16 16 3 1",
-	"       c None",
-	".      c #000000",
-	"+      c #FFFFFF",
-	"                ",
-	"                ",
-	"   .   .  ..    ",
-	"   ..  . .  .   ",
-	"   . . . .  .   ",
-	"   .  .. .  .   ",
-	"   .   .  ..    ",
-	"                ",
-	"                ",
-	"  ...  .   ..   ",
-	"   .  . . .     ",
-	"   .  ... . ..  ",
-	"   .  . . .  .  ",
-	"   .  . .  ..   ",
-	"                ",
-	"                "};
-
-/** width of both pixmaps, got using QPixmap::width() */
-static const int pixmapWidth = 16;
-/** height of both pixmaps, got using QPixmap::height() */
-static const int pixmapHeight = 16;
-
 /**
  * Constructor.
  *
  * @param dn directory name
  * @param fn filename
  */
-
 TaggedFile::TaggedFile(const QString& dn, const QString& fn) :
-	QListBoxItem(), dirname(dn), filename(fn), new_filename(fn)
+	dirname(dn), filename(fn), new_filename(fn)
 {
-	setText(fn);
-	setInSelection(FALSE);
 	changedV1 = FALSE;
 	changedV2 = FALSE;
-	// this two objects should be destructed when the program terminates.
-	// static QPixmap objects are not possible:
-	// "QPaintDevice: Must construct a QApplication before a QPaintDevice"
-	if (!nullPixmap) {
-		nullPixmap = new QPixmap((const char **)null_xpm);
-	}
-	if (!modifiedPixmap) {
-		modifiedPixmap = new QPixmap((const char **)modified_xpm);
-	}
-	if (!v1v2Pixmap) {
-		v1v2Pixmap = new QPixmap((const char **)v1v2_xpm);
-	}
-	if (!v1Pixmap) {
-		v1Pixmap = new QPixmap((const char **)v1_xpm);
-	}
-	if (!v2Pixmap) {
-		v2Pixmap = new QPixmap((const char **)v2_xpm);
-	}
-	if (!notagPixmap) {
-		notagPixmap = new QPixmap((const char **)notag_xpm);
-	}
 }
 
 /**
  * Destructor.
  */
-
-TaggedFile::~TaggedFile(void)
+TaggedFile::~TaggedFile()
 {
 }
 
@@ -554,7 +337,6 @@ void TaggedFile::setStandardTagsV2(const StandardTags *st,
 	}
 }
 
-#if QT_VERSION >= 300
 /**
  * Remove artist part from album string.
  * This is used when only the album is needed, but the regexp in
@@ -570,7 +352,6 @@ static void remove_artist(QString& album)
 		album.remove(0, pos + 3);
 	}
 }
-#endif
 
 /**
  * Get tags from filename.
@@ -597,30 +378,6 @@ static void remove_artist(QString& album)
  */
 void TaggedFile::getTagsFromFilename(StandardTags *st, QString fmt)
 {
-#if QT_VERSION < 300
-	int start, end;
-	const QString fn(getAbsFilename());
-	QRegExp re("[^/]+ - [^/]+/\\d\\d?\\d?[- ]+[^/]+\\.....?");
-	start = re.match(fn);
-	if (start != -1) {
-		end = fn.find(" - ", start);
-		st->artist = fn.mid(start, end - start);
-		start = end + 3;
-		end = fn.find("/", start);
-		st->album = fn.mid(start, end - start);
-		start = end + 1;
-		for (end = start + 1;; end++) {
-			if (fn[end] < '0' || fn[end] > '9') break;
-		}
-		st->track = fn.mid(start, end - start).toInt();
-		for (;; end++) {
-			if (fn[end] != ' ' && fn[end] != '-') break;
-		}
-		start = end;
-		end = fn.findRev('.');
-		st->title = fn.mid(start, end - start);
-	}
-#else
 	QRegExp re;
 	QString fn(getAbsFilename());
 
@@ -756,7 +513,6 @@ void TaggedFile::getTagsFromFilename(StandardTags *st, QString fmt)
 		remove_artist(st->album);
 		return;
 	}
-#endif
 }
 
 /**
@@ -854,69 +610,6 @@ void TaggedFile::getFilenameFromTags(const StandardTags *st, QString fmt)
 	new_filename = formatWithTags(st, fmt);
 }
 
-/**
- * Get height of item.
- *
- * @param lb listbox containing the item
- *
- * @return height.
- */
-int TaggedFile::height(const QListBox* lb) const
-{
-	int h = text().isEmpty() ? pixmapHeight :
-		QMAX(pixmapHeight, lb->fontMetrics().lineSpacing() + 1);
-	return QMAX(h, QApplication::globalStrut().height());
-}
-
-/**
- * Get width of item.
- *
- * @param lb listbox containing the item
- *
- * @return width.
- */
-int TaggedFile::width(const QListBox* lb) const
-{
-	if (text().isEmpty()) {
-		return QMAX(pixmapWidth * 2 + 6, QApplication::globalStrut().width());
-	}
-	return QMAX(pixmapWidth * 2 + 6 + lb->fontMetrics().width(text()), QApplication::globalStrut().width());
-}
-
-/**
- * Paint item.
- *
- * @param painter painter used
- */
-void TaggedFile::paint(QPainter *painter)
-{
-	static const QPixmap *tagpm[] = {
-		notagPixmap, v1Pixmap, v2Pixmap, v1v2Pixmap, nullPixmap
-	};
-	int tagpmIdx;
-	if (!isTagInformationRead()) {
-		tagpmIdx = 4;
-	} else {
-		tagpmIdx = 0;
-		if (hasTagV1()) {
-			tagpmIdx |= 1;
-		}
-		if (hasTagV2()) {
-			tagpmIdx |= 2;
-		}
-	}
-	painter->drawPixmap(3, 0, isChanged() ? *modifiedPixmap : *nullPixmap);
-	painter->drawPixmap(pixmapWidth + 3, 0, *tagpm[tagpmIdx]);
-	if (!text().isEmpty()) {
-		QFontMetrics fm = painter->fontMetrics();
-		painter->drawText(pixmapWidth * 2 + 5,
-						  pixmapHeight < fm.height() ?
-						  fm.ascent() + fm.leading() / 2 :
-						  pixmapHeight / 2 - fm.height() / 2 + fm.ascent(),
-						  text());
-	}
-}
-
 /**
  * Format a time string "h:mm:ss".
  * If the time is less than an hour, the hour is not put into the
@@ -985,10 +678,7 @@ bool TaggedFile::renameFile(const QString& fnOld, const QString& fnNew) const
  */
 QString TaggedFile::getCommentFieldName() const
 {
-	FileList* fileList = dynamic_cast<FileList*>(listBox());
-	const MiscConfig* miscCfg;
-	return (fileList && (miscCfg = fileList->getMiscConfig()) != 0) ?
-		miscCfg->m_commentName : MiscConfig::defaultCommentName;
+	return Kid3App::s_miscCfg.m_commentName;
 }
 
 /**
@@ -1000,11 +690,8 @@ QString TaggedFile::getCommentFieldName() const
 int TaggedFile::getTotalNumberOfTracksIfEnabled() const
 {
 	int numTracks = -1;
-	FileList* fileList = dynamic_cast<FileList*>(listBox());
-	const MiscConfig* miscCfg;
-	if (fileList && (miscCfg = fileList->getMiscConfig()) != 0 &&
-			miscCfg->m_enableTotalNumberOfTracks) {
-		numTracks = fileList->count();
+	if (Kid3App::s_miscCfg.m_enableTotalNumberOfTracks) {
+		numTracks = FileList::getNumberOfFiles();
 	}
 	return numTracks;
 }
@@ -1040,3 +727,27 @@ void TaggedFile::removeStandardTagsV2(const StandardTagsFilter& flt)
 	if (flt.m_enableTrack)   setTrackNumV2(0);
 	if (flt.m_enableGenre)   setGenreNumV2(0xff);
 }
+
+/**
+ * Get the format of tag 1.
+ *
+ * @return string describing format of tag 1,
+ *         e.g. "ID3v1.1", "ID3v2.3", "Vorbis", "APE",
+ *         QString::null if unknown.
+ */
+QString TaggedFile::getTagFormatV1() const
+{
+	return QString::null;
+}
+
+/**
+ * Get the format of tag 2.
+ *
+ * @return string describing format of tag 2,
+ *         e.g. "ID3v1.1", "ID3v2.3", "Vorbis", "APE",
+ *         QString::null if unknown.
+ */
+QString TaggedFile::getTagFormatV2() const
+{
+	return QString::null;
+}
